<?php
namespace Aws\OSIS\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon OpenSearch Ingestion** service.
 */
class OSISException extends AwsException {}
