<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'title' => 'Évolutions du produit',
    'note' => 'Remarque : malheureusement, cette page est uniquement en Anglais.',
];
