<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => 'Velkommen til din konto!',
    'dashboard_blank_description' => 'Monica er applikasjonen hvor du kan organisere alt du har å gjøre med personene du bryr deg om.',
    'dashboard_blank_cta' => 'Legg til din første kontakt',
    'dashboard_blank_illustration' => 'Illustrasjon av <a href=":url">Freepik</a>',

    'notes_title' => 'Du har ingen uthevede notater ennå.',

    'tab_recent_calls' => 'Nylige anrop',
    'tab_favorite_notes' => 'Favorittnotater',
    'tab_calls_blank' => 'Du har ikke logget noen samtaler enda.',
    'tab_debts' => 'Gjeld',
    'tab_debts_blank' => 'Du har ikke loggført noen gjeld ennå.',
    'tab_tasks' => 'Oppgaver',
    'tab_tasks_blank' => 'Du har ingen oppgaver enda.',

    'tasks_add_task_placeholder' => 'Hva handler denne oppgaven om?',
    'tasks_tab_your_contacts' => 'Oppgaver knyttet til kontaktene dine',
    'tasks_tab_your_tasks' => 'Dine oppgaver',
    'tasks_add_note' => 'Trykk <kbd>Enter</kbd> for å legge til oppgave.',
    'task_add_cta' => 'Ny oppgave',

    'debts_you_owe' => 'Du skylder',

    'statistics_contacts' => 'Kontakter',
    'statistics_activities' => 'Aktiviteter',
    'statistics_gifts' => 'Gaver',

    'reminders_next_months' => 'Hendelser de neste 3 månedene',
    'reminders_none' => 'Ingen påminnelser for denne måneden.',

    'product_changes' => 'Produktendringer',
    'product_view_details' => 'Vis detaljer',
];
