<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  25670 => 'Airtel',
  25671 => 'UTL',
  256720 => 'Smile',
  256724 => 'Hamilton Telecom',
  256726 => 'Tangerine',
  256728 => 'Talkio',
  25673 => 'Hamilton Telecom',
  25674 => 'Airtel',
  25675 => 'Airtel',
  25676 => 'MTN',
  25677 => 'MTN',
  25678 => 'MTN',
  25679 => 'Africell',
);
