<?php
namespace Aws\MigrationHub\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Migration Hub** service.
 */
class MigrationHubException extends AwsException {}
