<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Как был ваш день? Вы можете оценить его один раз в день.',
    'journal_come_back' => 'Спасибо. Вернитесь завтра, чтобы снова оценить свой день.',
    'journal_description' => 'Примечание: в журнале перечислены как записи в журнале вручную, так и автоматические записи, такие как действия, выполняемые с вашими контактами. Хотя вы можете удалить записи журнала вручную, вам придется удалить их непосредственно на странице контактов.',
    'journal_add' => 'Добавить запись в журнал',
    'journal_edit' => 'Редактировать запись журнала',
    'journal_empty' => 'Пустой журнал',
    'journal_created_at' => 'Создано в {date}',
    'journal_created_automatically' => 'Создано автоматически',
    'journal_entry_type_journal' => 'Запись журнала',
    'journal_entry_type_activity' => 'Активность',
    'journal_entry_rate' => 'Вы оценили свой день.',
    'journal_add_comment' => 'Хотите добавить комментарий (необязательно)?',
    'journal_show_comment' => 'Показать комментарий',
    'entry_delete_success' => 'Запись была удалена.',
    'journal_add_title' => 'Заголовок (не обязательно)',
    'journal_add_date' => 'Дата',
    'journal_add_post' => 'Содержимое',
    'journal_add_cta' => 'Сохранить',
    'journal_blank_cta' => 'Добавить вашу первую запись в журнал',
    'journal_blank_description' => 'В журнал вы можете добавлять записи о событиях в вашей жизни, чтобы сохранить их.',
    'delete_confirmation' => 'Вы уверены что хотите удалить эту запись?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
