<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  5993181 => 'Telcell',
  5993184 => 'Telcell',
  5993185 => 'Telcell',
  5993186 => 'Telcell',
  5993187 => 'Telcell',
  5993188 => 'Telcell',
  599319 => 'WIC',
  5994161 => 'Telcell',
  5994164 => 'WIC',
  5994165 => 'WIC',
  5994166 => 'WIC',
  5994167 => 'WIC',
  5994168 => 'WIC',
  5994169 => 'Satel',
  59970 => 'Digicel',
  59977 => 'Kla',
  59978 => 'Digicel',
  59979 => 'Chippie',
  599951 => 'Chippie',
  599952 => 'Chippie',
  599953 => 'Chippie',
  599954 => 'Chippie',
  599956 => 'Chippie',
  599957 => 'Antelecom',
  59996 => 'Digicel',
);
