<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Asesãu Kapuãma',
  'AD' => 'Ãdura',
  'AE' => 'Emiradu Árabi Yepewasuwaitá',
  'AF' => 'Afegãniretãma',
  'AG' => 'Ãtigua asuí Babuda',
  'AI' => 'Ãgira',
  'AL' => 'Aubãniya',
  'AM' => 'Arimẽniya',
  'AO' => 'Ãgura',
  'AQ' => 'Ãtartida',
  'AR' => 'Argẽtina',
  'AS' => 'Samua Amerikiwara',
  'AT' => 'Ausitiriya',
  'AU' => 'Ausitaraliya',
  'AW' => 'Aruba',
  'AX' => 'Kapuãma-ita Arãdi',
  'AZ' => 'Aseriretãma',
  'BA' => 'Businiya asuí Eseguwina',
  'BB' => 'Babadu',
  'BD' => 'Bãgaradexi',
  'BE' => 'Beujika',
  'BF' => 'Bukina Fasu',
  'BG' => 'Bugáriya',
  'BH' => 'Barẽi',
  'BI' => 'Burũdi',
  'BJ' => 'Benĩ',
  'BL' => 'Sã Batulumeu',
  'BM' => 'Bemuda',
  'BN' => 'Burunei',
  'BO' => 'Buríwia',
  'BQ' => 'Tetãma Iwiboí-ita Karíbi suí',
  'BR' => 'Brasiu',
  'BS' => 'Bayama',
  'BT' => 'Butãu',
  'BW' => 'Butisuwana',
  'BY' => 'Bieru-rúsiya',
  'BZ' => 'Belisi',
  'CA' => 'Kanadá',
  'CC' => 'Kapuãma-ita Kuku (Keering)',
  'CD' => 'Kũgu - Kĩxasa',
  'CF' => 'Repubirika Afirika-Piterapura',
  'CG' => 'Repubirika Kũguyara',
  'CH' => 'Suwisa',
  'CI' => 'Mafim Kupé',
  'CK' => 'Kapuãma-ita Kooki',
  'CL' => 'Xiri',
  'CM' => 'Puty-ita',
  'CN' => 'Xina',
  'CO' => 'Kurũbiya',
  'CR' => 'Kupé Rika',
  'CU' => 'Kuba',
  'CV' => 'Kabu Suikiri',
  'CW' => 'Kurasau',
  'CX' => 'Kapuãma Kiritima',
  'CY' => 'Xipiri',
  'CZ' => 'Xekiya',
  'DE' => 'Aremãya',
  'DG' => 'Diyegu Garasiya',
  'DJ' => 'Dijibuti',
  'DK' => 'Dinamaka',
  'DM' => 'Dominika',
  'DO' => 'Repubirika Duminikana',
  'DZ' => 'Argeriya',
  'EA' => 'Seuta asuí Merira',
  'EC' => 'Ekuadú',
  'EE' => 'Isituniya',
  'EG' => 'Egitu',
  'EH' => 'Saara Usidẽtawara',
  'ER' => 'Eritireya',
  'ES' => 'Isipãya',
  'ET' => 'Etiupiya',
  'FI' => 'Firãdiya',
  'FJ' => 'Fiyi',
  'FK' => 'Kapuãma-ita Mawina',
  'FM' => 'Mikuruneziya',
  'FO' => 'Kapuãma-ita Faruwe',
  'FR' => 'Frãsa',
  'GA' => 'Gabãu',
  'GB' => 'Reyinu Yepewasú',
  'GD' => 'Garanada',
  'GE' => 'Geugiya',
  'GF' => 'Giyana Frãsa yara',
  'GG' => 'Guwẽnisei',
  'GH' => 'Gana',
  'GI' => 'Gibarautá',
  'GL' => 'Guruẽrãdiya',
  'GM' => 'Gãbiya',
  'GN' => 'Giné',
  'GP' => 'Guadarupi',
  'GQ' => 'Giné Ekuaturiyau',
  'GR' => 'Geresiya',
  'GS' => 'Kapuãma-ita Geugiya Su asuí Sãduwixi Su',
  'GT' => 'Guatemara',
  'GU' => 'Guwã',
  'GW' => 'Giné Bisau',
  'GY' => 'Giyana',
  'HK' => 'Hũgi Kũgi, RAE Xina yara',
  'HN' => 'Ũdura',
  'HR' => 'Kuruwasiya',
  'HT' => 'Aití',
  'HU' => 'Ũgiriya',
  'IC' => 'Kapuãma-ita Kanariya',
  'ID' => 'Ĩdunesiya',
  'IE' => 'Irãda',
  'IL' => 'Isirayeu',
  'IM' => 'Mã Kapuãma',
  'IN' => 'Ĩdiya',
  'IQ' => 'Iraki',
  'IR' => 'Irã',
  'IS' => 'Isirãdiya',
  'IT' => 'Itariya',
  'JE' => 'Yesei',
  'JM' => 'Yamaika',
  'JO' => 'Yudãniya',
  'JP' => 'Nipõ',
  'KE' => 'Kẽniya',
  'KG' => 'Kirigiretãma',
  'KH' => 'Kãbuya',
  'KI' => 'Kiribati',
  'KM' => 'Kumure-ita',
  'KN' => 'Sã Kirituwãu suí Newi',
  'KP' => 'Kureya Nuti suí',
  'KR' => 'Kureya Su suí',
  'KW' => 'Kuwaiti',
  'KY' => 'Kapuãma-ita Kaimã',
  'KZ' => 'Kasakiretãma',
  'LA' => 'Rawo',
  'LB' => 'Ribanu',
  'LC' => 'Sãta Lusiya',
  'LI' => 'Rixitẽxitaĩ',
  'LK' => 'Siri Rãka',
  'LR' => 'Ribériya',
  'LS' => 'Resutu',
  'LT' => 'Rituwãniya',
  'LU' => 'Ruxẽbugu',
  'LV' => 'Retuniya',
  'LY' => 'Ribiya',
  'MA' => 'Maruku',
  'MC' => 'Mũnaku',
  'MD' => 'Mũduwa',
  'ME' => 'Mũteneguru',
  'MF' => 'Sã Matiyũ',
  'MG' => 'Madagasiká',
  'MH' => 'Kapuãma-ita Marshall',
  'MK' => 'Masedũniya',
  'ML' => 'Mari',
  'MM' => 'Miyamá (Bimãniya)',
  'MN' => 'Mũguriya',
  'MO' => 'Makau, RAE Xina yara',
  'MP' => 'Kapuãma-ita Mariyãna Nuti suí',
  'MQ' => 'Matinika',
  'MR' => 'Mauritaniya',
  'MS' => 'Mũtiserati',
  'MT' => 'Mauta',
  'MU' => 'Maurisiyu',
  'MV' => 'Maudiwa-ita',
  'MW' => 'Marawi',
  'MX' => 'Mẽsiku',
  'MY' => 'Malasiya',
  'MZ' => 'Musãbiki',
  'NA' => 'Namíbiya',
  'NC' => 'Karedũniya Pisasú',
  'NE' => 'Nige',
  'NF' => 'Kapuãma Norfolk',
  'NG' => 'Nigeriya',
  'NI' => 'Nicaraguwa',
  'NL' => 'Tetãma Iwiboí-ita',
  'NO' => 'Nuruwega',
  'NP' => 'Nepau',
  'NR' => 'Nauru',
  'NU' => 'Niwe',
  'NZ' => 'Serãdiya Pisasú',
  'OM' => 'Umã',
  'PA' => 'Panamã',
  'PE' => 'Peru',
  'PF' => 'Pulinesiya Frãsa yara',
  'PG' => 'Papuwa-Giné Pisasú',
  'PH' => 'Firipina',
  'PK' => 'Pakiretãma',
  'PL' => 'Puluniya',
  'PM' => 'Sã Peduru asuí Mikelãu',
  'PN' => 'Kapuãma-ita Pitcairn',
  'PR' => 'Igarapawa Riku',
  'PS' => 'Tetãma Paretinu-ita yara',
  'PT' => 'Putugau',
  'PW' => 'Parau',
  'PY' => 'Paraguwai',
  'QA' => 'Katara',
  'RE' => 'Yumuatirisawa',
  'RO' => 'Romẽniya',
  'RS' => 'Sewiya',
  'RU' => 'Rusiya',
  'RW' => 'Huãda',
  'SA' => 'Arawia Saudita',
  'SB' => 'Kapuãma-ita Sarumũ',
  'SC' => 'Seixeri',
  'SD' => 'Ausudã',
  'SE' => 'Suwesiya',
  'SG' => 'Sĩgapura',
  'SH' => 'Sãta Erena',
  'SI' => 'Esiruwẽniya',
  'SJ' => 'Siwaubati asuí Yã Mayeni',
  'SK' => 'Esiruwakiya',
  'SL' => 'Iwitera Leowa',
  'SM' => 'Sã Marino',
  'SN' => 'Senegau',
  'SO' => 'Somariya',
  'SR' => 'Suriname',
  'SS' => 'Ausudã Su suí',
  'ST' => 'Sã Tumé asuí Pirĩsipe',
  'SV' => 'Eru Sawadu',
  'SX' => 'Sĩti Maatẽ',
  'SY' => 'Siriya',
  'SZ' => 'Esuatíni',
  'TA' => 'Tiritãu Kũya',
  'TC' => 'Kapuãma-ita Tuka-ita asuí Kaiko-ita',
  'TD' => 'Xade',
  'TF' => 'Tetãma Su-ita Frãsa suí',
  'TG' => 'Togu',
  'TH' => 'Tairetãma',
  'TJ' => 'Tayikiretãma',
  'TK' => 'Tukerau',
  'TL' => 'Timu-Semusawa',
  'TM' => 'Turkuranaretãma',
  'TN' => 'Tunisiya',
  'TO' => 'Tõga',
  'TR' => 'Tukíya',
  'TT' => 'Tirinidadi asuí Tobagu',
  'TV' => 'Tuwaru',
  'TW' => 'Taiwã',
  'TZ' => 'Tãsaniya',
  'UA' => 'Ukarãniya',
  'UG' => 'Ugãda',
  'UM' => 'Kapuãma Kuiriwaita Apekatu EUA suí',
  'US' => 'Tetãma-ita Yepewasú',
  'UY' => 'Uruguwai',
  'UZ' => 'Yũbuesara-retãma',
  'VA' => 'Watikanu Tawa-wasu',
  'VC' => 'Sã Wisẽti asuí Garanadĩna-ita',
  'VE' => 'Wenesuera',
  'VG' => 'Kapuã-ita Viyẽ-ita Biritãnika-ita',
  'VI' => 'Kapuã-ira Viyẽ-ita Amerikana-ita',
  'VN' => 'Wiyetinã',
  'VU' => 'Wanuatu',
  'WF' => 'Wari asuí Futuna',
  'WS' => 'Samowa',
  'XK' => 'Kusuwu',
  'YE' => 'Yemẽ',
  'YT' => 'Mayuti',
  'ZA' => 'Afirika Su suí',
  'ZM' => 'Sãbiya',
  'ZW' => 'Sĩbabuwe',
);
