<?php
// This file was auto-generated from sdk-root/src/data/emr-containers/2020-10-01/paginators-1.json
return [ 'pagination' => [ 'ListJobRuns' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'jobRuns', ], 'ListJobTemplates' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'templates', ], 'ListManagedEndpoints' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'endpoints', ], 'ListSecurityConfigurations' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'securityConfigurations', ], 'ListVirtualClusters' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'virtualClusters', ], ],];
