<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  35813 => 'North Karelia',
  35814 => 'Central Finland',
  35815 => 'Mikkeli',
  35816 => 'Lapland',
  35817 => 'Kuopio',
  35819 => 'Uusimaa',
  35821 => 'Turku/Pori',
  35822 => 'Turku/Pori',
  35823 => 'Turku/Pori',
  35824 => 'Turku/Pori',
  35825 => 'Turku/Pori',
  35826 => 'Turku/Pori',
  35827 => 'Turku/Pori',
  35828 => 'Turku/Pori',
  35831 => 'Häme',
  35832 => 'Häme',
  35833 => 'Häme',
  35834 => 'Häme',
  35835 => 'Häme',
  35836 => 'Häme',
  35837 => 'Häme',
  35838 => 'Häme',
  35851 => 'Kymi',
  35852 => 'Kymi',
  35853 => 'Kymi',
  35854 => 'Kymi',
  35855 => 'Kymi',
  35856 => 'Kymi',
  35857 => 'Kymi',
  35858 => 'Kymi',
  35861 => 'Vaasa',
  35862 => 'Vaasa',
  35863 => 'Vaasa',
  35864 => 'Vaasa',
  35865 => 'Vaasa',
  35866 => 'Vaasa',
  35867 => 'Vaasa',
  35868 => 'Vaasa',
  35881 => 'Oulu',
  35882 => 'Oulu',
  35883 => 'Oulu',
  35884 => 'Oulu',
  35885 => 'Oulu',
  35886 => 'Oulu',
  35887 => 'Oulu',
  35888 => 'Oulu',
  3589 => 'Helsinki',
  35890 => 'Uusimaa',
);
