<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  238221 => 'Ribeira Grande, Santo Antão',
  238222 => 'Porto Novo, Santo Antão',
  238223 => 'Paúl, Santo Antão',
  238224 => 'Cocoli, Santo Antão',
  238225 => 'Ponta do Sol, Santo Antão',
  238226 => 'Manta Velha/Chã de Igreja  (Santo Antão Island)',
  238227 => 'Lajedos/Alto Mira (Santo Antão Island)',
  238230 => 'Mindelo, São Vicente',
  238231 => 'Mindelo, São Vicente',
  238232 => 'Mindelo, São Vicente',
  238235 => 'Ribeira Brava, São Nicolau',
  238236 => 'Tarrafal de São Nicolau, São Nicolau',
  238237 => 'Fajã, São Nicolau',
  238238 => 'Praia Branca, São Nicolau',
  238241 => 'Espargos, Sal',
  238242 => 'Santa Maria, Sal',
  238251 => 'Sal Rei, Boa Vista',
  238252 => 'Funda das Figueiras, Boa Vista',
  238255 => 'Vila do Maio, Maio',
  238256 => 'Calheta, Maio',
  238260 => 'Praia, Santiago',
  238261 => 'Praia, Santiago',
  238262 => 'Praia, Santiago',
  238263 => 'Praia, Santiago',
  238264 => 'Praia, Santiago',
  238265 => 'Santa Catarina, Santiago',
  238266 => 'Tarrafal, Santiago',
  238267 => 'Cidade Velha, Santiago',
  238268 => 'São Domingos, Santiago',
  238269 => 'Pedra Badejo, Santiago',
  238271 => 'Orgão/São Jorge (Santiago Island)',
  238272 => 'Picos, Santiago',
  238273 => 'Calheta de São Miguel, Santiago',
  238281 => 'São Filipe, Fogo',
  238282 => 'Cova Figueira, Fogo',
  238283 => 'Mosteiros, Fogo',
  238284 => 'São Jorge, Fogo',
  238285 => 'Nova Sintra, Brava',
);
