<?php
namespace Aws\MigrationHubRefactorSpaces\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Migration Hub Refactor Spaces** service.
 */
class MigrationHubRefactorSpacesException extends AwsException {}
