<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9890 => 'ایرانسل',
  9891 => 'همراه اول',
  9892 => 'رایتل',
  9893 => 'ایرانسل',
  98931 => 'اسپادان',
  98932 => 'تالیا',
  98934 => 'تله‌کیش',
  98990 => 'همراه اول',
  98991 => 'همراه اول',
  98994 => 'همراه اول',
  98996 => 'همراه اول',
  989981 => 'شاتل موبایل',
  989982 => 'شاتل موبایل',
  9899900 => 'لوتوس‌تل',
  9899902 => 'همراه اول',
  989991 => 'ایرانسل',
  989998 => 'رایتل',
  9899996 => 'رایتل',
  9899997 => 'رایتل',
  9899998 => 'رایتل',
  9899999 => 'رایتل',
);
