<?php
namespace Aws\IoTAnalytics\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Analytics** service.
 */
class IoTAnalyticsException extends AwsException {}
