<?php
// This file was auto-generated from sdk-root/src/data/appfabric/2023-05-19/paginators-1.json
return [ 'pagination' => [ 'ListAppAuthorizations' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'appAuthorizationSummaryList', ], 'ListAppBundles' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'appBundleSummaryList', ], 'ListIngestionDestinations' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'ingestionDestinations', ], 'ListIngestions' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'ingestions', ], ],];
