<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Ἀνδόρα',
  'AE' => 'Ἠνωμένα Ἀραβικὰ Ἐμιράτα',
  'AF' => 'Ἀφγανιστάν',
  'AG' => 'Ἀντίγκουα καὶ Μπαρμπούντα',
  'AI' => 'Ἀνγκουίλα',
  'AL' => 'Ἀλβανία',
  'AM' => 'Ἀρμενία',
  'AO' => 'Ἀνγκόλα',
  'AQ' => 'Ἀνταρκτική',
  'AR' => 'Ἀργεντινή',
  'AS' => 'Ἀμερικανικὴ Σαμόα',
  'AT' => 'Αὐστρία',
  'AU' => 'Αὐστραλία',
  'AW' => 'Ἀρούμπα',
  'AZ' => 'Ἀζερμπαϊτζάν',
  'BA' => 'Βοσνία - Ἐρζεγοβίνη',
  'BM' => 'Βερμοῦδες',
  'CC' => 'Νῆσοι Κόκος (Κήλινγκ)',
  'CD' => 'Κονγκό, Λαϊκὴ Δημοκρατία τοῦ',
  'CF' => 'Κεντροαφρικανικὴ Δημοκρατία',
  'CH' => 'Ἑλβετία',
  'CK' => 'Νῆσοι Κούκ',
  'CX' => 'Νῆσος Χριστουγέννων',
  'DO' => 'Δομινικανὴ Δημοκρατία',
  'DZ' => 'Ἀλγερία',
  'EC' => 'Ἰσημερινός',
  'EE' => 'Ἐσθονία',
  'EG' => 'Αἴγυπτος',
  'EH' => 'Δυτικὴ Σαχάρα',
  'ER' => 'Ἐρυθραία',
  'ES' => 'Ἱσπανία',
  'ET' => 'Αἰθιοπία',
  'FM' => 'Μικρονησία, Ὁμόσπονδες Πολιτεῖες τῆς',
  'FO' => 'Νῆσοι Φερόες',
  'GB' => 'Ἡνωμένο Βασίλειο',
  'GF' => 'Γαλλικὴ Γουιάνα',
  'GQ' => 'Ἰσημερινὴ Γουινέα',
  'GR' => 'Ἑλλάδα',
  'HK' => 'Χὸνγκ Κόνγκ, Εἰδικὴ Διοικητικὴ Περιφέρεια τῆς Κίνας',
  'HN' => 'Ὁνδούρα',
  'HT' => 'Ἁϊτή',
  'HU' => 'Οὑγγαρία',
  'ID' => 'Ἰνδονησία',
  'IE' => 'Ἰρλανδία',
  'IL' => 'Ἰσραήλ',
  'IN' => 'Ἰνδία',
  'IQ' => 'Ἰράκ',
  'IR' => 'Ἰράν, Ἰσλαμικὴ Δημοκρατία τοῦ',
  'IS' => 'Ἰσλανδία',
  'IT' => 'Ἰταλία',
  'JO' => 'Ἰορδανία',
  'JP' => 'Ἰαπωνία',
  'KN' => 'Σαὶντ Κὶτς καὶ Νέβις',
  'KY' => 'Νῆσοι Κέιμαν',
  'LA' => 'Λατινικὴ Ἀμερική',
  'LC' => 'Ἁγία Λουκία',
  'LK' => 'Σρὶ Λάνκα',
  'LU' => 'Λουξεμβοῦργο',
  'MD' => 'Μολδαβία, Δημοκρατία τῆς',
  'MH' => 'Νῆσοι Μάρσαλ',
  'ML' => 'Μαλί',
  'MO' => 'Μακάο, Εἰδικὴ Διοικητικὴ Περιφέρεια τῆς Κίνας',
  'MP' => 'Νῆσοι Βόρειες Μαριάνες',
  'NF' => 'Νῆσος Νόρφολκ',
  'NL' => 'Ὁλλανδία',
  'OM' => 'Ὀμάν',
  'PF' => 'Γαλλικὴ Πολυνησία',
  'PM' => 'Σαὶντ Πιὲρ καὶ Μικελόν',
  'PS' => 'Παλαιστινιακὰ Ἐδάφη',
  'SA' => 'Σαουδικὴ Ἀραβία',
  'SB' => 'Νῆσοι Σολομῶντος',
  'SH' => 'Ἁγία Ἑλένη',
  'SJ' => 'Νῆσοι Σβάλμπαρ καὶ Γιὰν Μαγιέν',
  'SM' => 'Ἅγιος Μαρίνος',
  'ST' => 'Σάο Τομὲ καὶ Πρίνσιπε',
  'SV' => 'Ἒλ Σαλβαδόρ',
  'SY' => 'Συρία, Ἀραβικὴ Δημοκρατία τῆς',
  'TC' => 'Νῆσοι Τὲρκς καὶ Κάικος',
  'TD' => 'Τσάντ',
  'TF' => 'Γαλλικὰ Νότια Ἐδάφη',
  'TL' => 'Ἀνατολικὸ Τιμόρ',
  'TT' => 'Τρινιδὰδ καὶ Τομπάγκο',
  'UA' => 'Οὐκρανία',
  'UG' => 'Οὐγκάντα',
  'UM' => 'Ἀπομακρυσμένες Νησίδες τῶν Ἡνωμένων Πολιτειῶν',
  'US' => 'Ἡνωμένες Πολιτεῖες',
  'UY' => 'Οὐρουγουάη',
  'UZ' => 'Οὐζμπεκιστάν',
  'VA' => 'Ἁγία Ἕδρα (Βατικανό)',
  'VC' => 'Ἅγιος Βικέντιος καὶ Γρεναδίνες',
  'VG' => 'Βρετανικὲς Παρθένοι Νῆσοι',
  'VI' => 'Ἀμερικανικὲς Παρθένοι Νῆσοι',
  'WF' => 'Νῆσοι Οὐάλλις καὶ Φουτουνά',
  'YE' => 'Ὑεμένη',
  'ZA' => 'Νότια Ἀφρική',
);
