<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'user_unauthenticated' => 'You need to log in before doing a Webauthn authentication',
    'auth_data_not_found' => 'Authentication data not found',
    'create_data_not_found' => 'Register data not found',
    'object_not_found' => 'Object not found',

];
