<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  25522 => 'Dar-Es-Salaam',
  25523 => 'Coast/Morogoro/Lindi/Mtwara',
  25524 => 'Zanzibar',
  25525 => 'Mbeya/Songwe/Ruvuma/Katavi/Rukwa',
  25526 => 'Dodoma/Iringa/Njombe/Singida/Tabora',
  25527 => 'Arusha/Manyara/Kilimanjaro/Tanga',
  25528 => 'Mwanza/Shinyanga/Mara/Geita/Simiyu/Kagera/Kigoma',
);
