<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Sim',
    'no' => 'Não',
    'update' => 'Atualizar',
    'save' => 'Salvar',
    'add' => 'Adicionar',
    'cancel' => 'Cancelar',
    'confirm' => 'Confirmar',
    'delete_confirm' => 'Tem certeza?',
    'delete' => 'Excluir',
    'edit' => 'Editar',
    'upload' => 'Upload',
    'download' => 'Baixar',
    'save_close' => 'Salvar e fechar',
    'close' => 'Fechar',
    'copy' => 'Copiar',
    'create' => 'Criar',
    'remove' => 'Remover',
    'revoke' => 'Revogar',
    'done' => 'Concluído',
    'back' => 'Voltar',
    'verify' => 'Verificar',
    'new' => 'novo',
    'unknown' => 'Eu não sei',
    'load_more' => 'Carregar mais',
    'loading' => 'Carregando…',
    'with' => 'com',
    'today' => 'hoje',
    'yesterday' => 'ontem',
    'another_day' => 'outro dia',
    'date' => 'Data',
    'type' => 'Tipo',
    'zoom' => 'Zoom',
    'upgrade' => 'Assine para desbloquear',
    'percent_uploaded' => '{percent}% enviado',
    'retry' => 'Tentar novamente',
    'filter' => 'Filtrar lista',
    'go_back' => 'Voltar',
    'file_selected' => 'Um arquivo selecionado…|{count} arquivos selecionados…',

    'application_title' => 'Monica – Gerenciador de relacionamento pessoal',
    'application_description' => 'Monica é uma ferramenta para gerenciar suas interações com seus amigos, familiares e pessoas queridas.',
    'application_og_title' => 'Fortaleça seu relacionamento com seus entes queridos. CRM online gratuito para amigos e família.',

    'markdown_description' => 'Want to format your text in a nice way? We support Markdown to add bold, italic, lists and more.',
    'markdown_link' => 'Ler documentação',

    'header_settings_link' => 'Configurações',
    'header_logout_link' => 'Sair',
    'header_changelog_link' => 'Atualizações de produtos',

    'main_nav_cta' => 'Adicionar contatos',
    'main_nav_dashboard' => 'Dashboard',
    'main_nav_family' => 'Contatos',
    'main_nav_journal' => 'Diário',
    'main_nav_activities' => 'Atividades',
    'main_nav_tasks' => 'Tarefas',

    'footer_remarks' => 'Comentários?',
    'footer_send_email' => 'Envie-nos um email',
    'footer_privacy' => 'Política de Privacidade',
    'footer_release' => 'Notas da versão',
    'footer_newsletter' => 'Newsletter',
    'footer_source_code' => 'Contribuir',
    'footer_version' => 'Versão: :version',
    'footer_new_version' => 'Uma nova versão de Monica está disponível',

    'footer_modal_version_whats_new' => 'Novidades',
    'footer_modal_version_release_away' => 'Sua instalação está 1 versão atrás da versão mais recente. Atualize para aproveitar as novidades.|Sua instalação está :number versões atrás da versão mais recente. Atualize para aproveitar as novidades.',

    'breadcrumb_dashboard' => 'Dashboard',
    'breadcrumb_list_contacts' => 'Lista de contatos',
    'breadcrumb_archived_contacts' => 'Contatos arquivados',
    'breadcrumb_journal' => 'Diário',
    'breadcrumb_settings' => 'Configurações',
    'breadcrumb_settings_export' => 'Exportar',
    'breadcrumb_settings_users' => 'Usuários',
    'breadcrumb_settings_users_add' => 'Adicionar usuário',
    'breadcrumb_settings_subscriptions' => 'Assinatura',
    'breadcrumb_settings_import' => 'Importar',
    'breadcrumb_settings_import_report' => 'Relatório de importação',
    'breadcrumb_settings_import_upload' => 'Enviar',
    'breadcrumb_settings_tags' => 'Etiquetas',
    'breadcrumb_add_significant_other' => 'Adicionar companheiro(a)',
    'breadcrumb_edit_significant_other' => 'Editar companheiro(a)',
    'breadcrumb_add_note' => 'Adicionar nota',
    'breadcrumb_edit_note' => 'Editar nota',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV Resources',
    'breadcrumb_edit_introductions' => 'Como se conheceram',
    'breadcrumb_settings_personalization' => 'Personalização',
    'breadcrumb_settings_security' => 'Segurança',
    'breadcrumb_settings_security_2fa' => 'Autenticação de dois fatores',
    'breadcrumb_profile' => 'Perfil de :name',

    'gender_male' => 'Homem',
    'gender_female' => 'Mulher',
    'gender_none' => 'Prefiro não dizer',
    'gender_no_gender' => 'Sem gênero',

    'error_title' => 'Ops! Algo deu errado.',
    'error_unauthorized' => 'Você não tem permissão para editar este recurso.',
    'error_user_account' => 'Esse usuário não pertence à conta fornecida.',
    'error_save' => 'Ocorreu um erro ao tentar salvar os dados.',
    'error_try_again' => 'Algo deu errado. Por favor, tente novamente.',
    'error_id' => 'Error ID: :id',
    'error_unavailable' => 'Serviço indisponível',
    'error_maintenance' => 'Manutenção em andamento. Voltaremos em breve.',
    'error_help' => 'Voltaremos em breve.',
    'error_twitter' => 'Siga-nos <a href="https://twitter.com/:twitter">no Twitter </a> para saber quando voltamos.',
    'error_no_term' => 'Não há nenhuma regra para esta instância até o momento.',

    'default_save_success' => 'Dados salvos com sucesso!',

    'compliance_title' => 'Desculpa pelo incômodo.',
    'compliance_desc' => 'Alteramos nossos <a href=":urlterm" hreflang=":hreflang">Termos de Uso</a> e <a href=":url" hreflang=":hreflang">Política de Privacidade</a>. Por lei, solicitamos que você os revise e aceite ambos para que possa continuar usando sua conta.',
    'compliance_desc_end' => 'We don’t do anything nasty with your data or account and will never do.',
    'compliance_terms' => 'Aceitar os novos Termos e Política de Privacidade',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Relacionamentos amorosos',
    'relationship_type_group_family' => 'Relacionamentos familiares',
    'relationship_type_group_friend' => 'Relacionamentos de amizade',
    'relationship_type_group_work' => 'Relacionamentos profissionais',
    'relationship_type_group_other' => 'Outros tipos de relações',

    'relationship_type_partner' => 'companheiro',
    'relationship_type_partner_female' => 'companheira',
    'relationship_type_partner_male' => 'significant other',
    'relationship_type_partner_with_name' => 'companheiro de :name',
    'relationship_type_partner_female_with_name' => 'companheira de :name',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'esposo',
    'relationship_type_spouse_female' => 'esposa',
    'relationship_type_spouse_male' => 'marido',
    'relationship_type_spouse_with_name' => 'esposo de :name',
    'relationship_type_spouse_female_with_name' => 'esposa de :name',
    'relationship_type_spouse_male_with_name' => 'marido de :name',

    'relationship_type_date' => 'namorado',
    'relationship_type_date_female' => 'namorada',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => 'namorado de :name',
    'relationship_type_date_female_with_name' => 'namorada de :name',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'amante',
    'relationship_type_lover_female' => 'amante',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => 'amante de :name',
    'relationship_type_lover_female_with_name' => 'amante de :name',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'apaixonado por',
    'relationship_type_inlovewith_female' => 'apaixonada por',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => 'alguém que :name está apaixonado',
    'relationship_type_inlovewith_female_with_name' => 'alguém que :name está apaixonada',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'amado por',
    'relationship_type_lovedby_female' => 'amada por',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => 'amor secreto de :name',
    'relationship_type_lovedby_female_with_name' => 'amor secreto de :name',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'ex-namorada',
    'relationship_type_ex_male' => 'ex-namorado',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => 'ex-namorada de :name',
    'relationship_type_ex_male_with_name' => 'ex-namorado de :name',

    'relationship_type_parent' => 'pais',
    'relationship_type_parent_female' => 'mãe',
    'relationship_type_parent_male' => 'pai',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => 'mãe de :name',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'child',
    'relationship_type_child_female' => 'filha',
    'relationship_type_child_male' => 'filho',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => 'filha de :name',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'madrasta',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => 'madrasta de :name',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'enteada',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => 'enteada de :name',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sibling',
    'relationship_type_sibling_female' => 'irmã',
    'relationship_type_sibling_male' => 'brother',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => 'irmã de :name',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'grandparent',
    'relationship_type_grandparent_female' => 'grandmother',
    'relationship_type_grandparent_male' => 'grandfather',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'grandchild',
    'relationship_type_grandchild_female' => 'granddaughter',
    'relationship_type_grandchild_male' => 'grandson',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => 'neta da :name’s',
    'relationship_type_grandchild_male_with_name' => 'neto do :name\'s',

    'relationship_type_uncle' => 'tio',
    'relationship_type_uncle_female' => 'tia',
    'relationship_type_uncle_male' => 'uncle',
    'relationship_type_uncle_with_name' => 'tio de :name',
    'relationship_type_uncle_female_with_name' => 'tia de :name',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'sobrinho',
    'relationship_type_nephew_female' => 'sobrinha',
    'relationship_type_nephew_male' => 'nephew',
    'relationship_type_nephew_with_name' => 'sobrinho de :name',
    'relationship_type_nephew_female_with_name' => 'sobrinha de :name',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'primo',
    'relationship_type_cousin_female' => 'prima',
    'relationship_type_cousin_male' => 'cousin',
    'relationship_type_cousin_with_name' => 'primo de :name',
    'relationship_type_cousin_female_with_name' => 'prima de :name',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'madrinha',
    'relationship_type_godfather_male' => 'godfather',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => 'madrinha de :name',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'afilhada',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => 'afilhada de :name',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'amigo',
    'relationship_type_friend_female' => 'amiga',
    'relationship_type_friend_male' => 'amigo',
    'relationship_type_friend_with_name' => 'amigo de :name',
    'relationship_type_friend_female_with_name' => 'amiga de :name',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'melhor amigo',
    'relationship_type_bestfriend_female' => 'melhor amiga',
    'relationship_type_bestfriend_male' => 'melhor amigo',
    'relationship_type_bestfriend_with_name' => 'melhor amigo de :name',
    'relationship_type_bestfriend_female_with_name' => 'melhor amiga de :name',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'colega',
    'relationship_type_colleague_female' => 'colega',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => 'colega de :name',
    'relationship_type_colleague_female_with_name' => 'colega de :name',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'chefe',
    'relationship_type_boss_female' => 'chefa',
    'relationship_type_boss_male' => 'chefe',
    'relationship_type_boss_with_name' => 'chefe de :name',
    'relationship_type_boss_female_with_name' => ':name do chefe',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'funcionário',
    'relationship_type_subordinate_female' => 'funcionário',
    'relationship_type_subordinate_male' => 'funcionário',
    'relationship_type_subordinate_with_name' => ':name do funcionário',
    'relationship_type_subordinate_female_with_name' => ':name do funcionario',
    'relationship_type_subordinate_male_with_name' => 'Funcionário do :name’s',

    'relationship_type_mentor' => 'mentor',
    'relationship_type_mentor_female' => 'mentora',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => 'mentor de :name',
    'relationship_type_mentor_female_with_name' => 'mentora de :name',
    'relationship_type_mentor_male_with_name' => 'mentor de :name’s',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'ex wife',
    'relationship_type_ex_husband_male' => 'ex-husband',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => ':name’s ex wife',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Amor',
    'emotion_primary_joy' => 'Alegria',
    'emotion_primary_surprise' => 'Surpresa',
    'emotion_primary_anger' => 'Raiva',
    'emotion_primary_sadness' => 'Tristeza',
    'emotion_primary_fear' => 'Medo',

    'emotion_secondary_affection' => 'Afeição',
    'emotion_secondary_lust' => 'Cobiça',
    'emotion_secondary_longing' => 'Desejo',
    'emotion_secondary_cheerfulness' => 'Felicidade',
    'emotion_secondary_zest' => 'Entusiasmo',
    'emotion_secondary_contentment' => 'Satisfação',
    'emotion_secondary_pride' => 'Orgulho',
    'emotion_secondary_optimism' => 'Otimismo',
    'emotion_secondary_enthrallment' => 'Encantado',
    'emotion_secondary_relief' => 'Alívio',
    'emotion_secondary_surprise' => 'Surpreso',
    'emotion_secondary_irritation' => 'Irritação',
    'emotion_secondary_exasperation' => 'Fúria',
    'emotion_secondary_rage' => 'Raiva',
    'emotion_secondary_disgust' => 'Nojo',
    'emotion_secondary_envy' => 'Inveja',
    'emotion_secondary_suffering' => 'Dor',
    'emotion_secondary_sadness' => 'Tristeza',
    'emotion_secondary_disappointment' => 'Desapontado',
    'emotion_secondary_shame' => 'Vergonha',
    'emotion_secondary_neglect' => 'Esquecido',
    'emotion_secondary_sympathy' => 'Simpatia',
    'emotion_secondary_horror' => 'Repúdio',
    'emotion_secondary_nervousness' => 'Nervosismo',

    'emotion_adoration' => 'Adorado',
    'emotion_affection' => 'Afeição',
    'emotion_love' => 'Amor',
    'emotion_fondness' => 'Apreço',
    'emotion_liking' => 'Carinho',
    'emotion_attraction' => 'Atração',
    'emotion_caring' => 'Cuidado',
    'emotion_tenderness' => 'Ternura',
    'emotion_compassion' => 'Compaixão',
    'emotion_sentimentality' => 'Sentimental',
    'emotion_arousal' => 'Agitação',
    'emotion_desire' => 'Desejo',
    'emotion_lust' => 'Cobiça',
    'emotion_passion' => 'Paixão',
    'emotion_infatuation' => 'Fascínio',
    'emotion_longing' => 'Desejo',
    'emotion_amusement' => 'Diversão',
    'emotion_bliss' => 'Euforia',
    'emotion_cheerfulness' => 'Felicidade',
    'emotion_gaiety' => 'Alegria',
    'emotion_glee' => 'Alegria',
    'emotion_jolliness' => 'Contente',
    'emotion_joviality' => 'Jovialidade',
    'emotion_joy' => 'Alegria',
    'emotion_delight' => 'Deleite',
    'emotion_enjoyment' => 'Prazer',
    'emotion_gladness' => 'Alegria',
    'emotion_happiness' => 'Felicidade',
    'emotion_jubilation' => 'Júbilo',
    'emotion_elation' => 'Exaltação',
    'emotion_satisfaction' => 'Satisfação',
    'emotion_ecstasy' => 'Êxtase',
    'emotion_euphoria' => 'Euforia',
    'emotion_enthusiasm' => 'Entusiasmo',
    'emotion_zeal' => 'Zelo',
    'emotion_zest' => 'Animação',
    'emotion_excitement' => 'Excitação',
    'emotion_thrill' => 'Emocionado/a',
    'emotion_exhilaration' => 'Alegria',
    'emotion_contentment' => 'Satisfação',
    'emotion_pleasure' => 'Prazer',
    'emotion_pride' => 'Orgulho',
    'emotion_eagerness' => 'Ansiedade',
    'emotion_hope' => 'Esperança',
    'emotion_optimism' => 'Otimismo',
    'emotion_enthrallment' => 'Encanto',
    'emotion_rapture' => 'Êxtase',
    'emotion_relief' => 'Alívio',
    'emotion_amazement' => 'Incrível',
    'emotion_surprise' => 'Surpresa',
    'emotion_astonishment' => 'Espanto',
    'emotion_aggravation' => 'Encrenca',
    'emotion_irritation' => 'Irritação',
    'emotion_agitation' => 'Agitação',
    'emotion_annoyance' => 'Aborrecimento',
    'emotion_grouchiness' => 'Resmungar',
    'emotion_grumpiness' => 'Mau humor',
    'emotion_exasperation' => 'Exasperação',
    'emotion_frustration' => 'Frustração',
    'emotion_anger' => 'Raiva',
    'emotion_rage' => 'Raiva',
    'emotion_outrage' => 'Ultraje',
    'emotion_fury' => 'Fúria',
    'emotion_wrath' => 'Ira',
    'emotion_hostility' => 'Hostilidade',
    'emotion_ferocity' => 'Ferocidade',
    'emotion_bitterness' => 'Amargura',
    'emotion_hate' => 'Ódio',
    'emotion_loathing' => 'Repulsa',
    'emotion_scorn' => 'Desprezo',
    'emotion_spite' => 'Rancor',
    'emotion_vengefulness' => 'Vingança',
    'emotion_dislike' => 'Desgosto',
    'emotion_resentment' => 'Ressentimento',
    'emotion_disgust' => 'Nojo',
    'emotion_revulsion' => 'Repulsa',
    'emotion_contempt' => 'Desdém',
    'emotion_envy' => 'Inveja',
    'emotion_jealousy' => 'Ciúme',
    'emotion_agony' => 'Agonia',
    'emotion_suffering' => 'Sofrimento',
    'emotion_hurt' => 'Magoar',
    'emotion_anguish' => 'Angústia',
    'emotion_depression' => 'Muito triste',
    'emotion_despair' => 'Desespero',
    'emotion_hopelessness' => 'Desesperança',
    'emotion_gloom' => 'Melancolia',
    'emotion_glumness' => 'Desânimo',
    'emotion_sadness' => 'Tristeza',
    'emotion_unhappiness' => 'Infelicidade',
    'emotion_grief' => 'Pesar',
    'emotion_sorrow' => 'Aflição',
    'emotion_woe' => 'Problemão',
    'emotion_misery' => 'Miséria',
    'emotion_melancholy' => 'Melancólico',
    'emotion_dismay' => 'Consternado',
    'emotion_disappointment' => 'Decepção',
    'emotion_displeasure' => 'Desgosto',
    'emotion_guilt' => 'Culpa',
    'emotion_shame' => 'Vergonha',
    'emotion_regret' => 'Arrepender',
    'emotion_remorse' => 'Remorso',
    'emotion_alienation' => 'Alienação',
    'emotion_isolation' => 'Isolamento',
    'emotion_neglect' => 'Negligência',
    'emotion_loneliness' => 'Solidão',
    'emotion_rejection' => 'Rejeição',
    'emotion_homesickness' => 'Saudade',
    'emotion_defeat' => 'Derrota',
    'emotion_dejection' => 'Abatido',
    'emotion_insecurity' => 'Insegurança',
    'emotion_embarrassment' => 'Constrangimento',
    'emotion_humiliation' => 'Humilhação',
    'emotion_insult' => 'Insulto',
    'emotion_pity' => 'Pena',
    'emotion_sympathy' => 'Simpatia',
    'emotion_alarm' => 'Alarme',
    'emotion_shock' => 'Choque',
    'emotion_fear' => 'Medo',
    'emotion_fright' => 'Susto',
    'emotion_horror' => 'Horror',
    'emotion_terror' => 'Terror',
    'emotion_panic' => 'Pânico',
    'emotion_hysteria' => 'Histeria',
    'emotion_mortification' => 'Mortificação',
    'emotion_anxiety' => 'Ansiedade',
    'emotion_nervousness' => 'Nervosismo',
    'emotion_tenseness' => 'Tensão',
    'emotion_uneasiness' => 'Inquietação',
    'emotion_apprehension' => 'Apreensão',
    'emotion_worry' => 'Preocupação',
    'emotion_distress' => 'Angústia',
    'emotion_dread' => 'Pavor',

    // weather
    'weather_sunny' => 'Ensolarado',
    'weather_clear' => 'Limpo',
    'weather_clear-day' => 'Limpo',
    'weather_clear-night' => 'Noite limpa',
    'weather_light-drizzle' => 'Chuvisco leve',
    'weather_patchy-light-drizzle' => 'Garoa leve irregular',
    'weather_patchy-light-rain' => 'Chuva leve irregular',
    'weather_light-rain' => 'Chuva leve',
    'weather_moderate-rain-at-times' => 'Chuva moderada ocasional',
    'weather_moderate-rain' => 'Chuva moderada',
    'weather_patchy-rain-possible' => 'Possibilidade de chuva',
    'weather_heavy-rain-at-times' => 'Chuva forte ocasional',
    'weather_heavy-rain' => 'Chuva forte',
    'weather_light-freezing-rain' => 'Frio com chuva leve',
    'weather_moderate-or-heavy-freezing-rain' => 'Frio com chuva moderada ou pesada',
    'weather_light-sleet' => 'Granizo fraco',
    'weather_moderate-or-heavy-rain-shower' => 'Chuvisco moderado ou pesado',
    'weather_light-rain-shower' => 'Chuva leve',
    'weather_torrential-rain-shower' => 'Chuva torrencial',
    'weather_rain' => 'Chuva',
    'weather_snow' => 'Neve',
    'weather_blowing-snow' => 'Nevando',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Neve fraca',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Neve moderada',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Neve intensa',
    'weather_light-snow-showers' => 'Pancadas leves de neve',
    'weather_moderate-or-heavy-snow-showers' => 'Pancadas de neve moderadas ou fortes',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Granizo moderado ou forte',
    'weather_light-sleet-showers' => 'Pancadas leves de granizo',
    'weather_moderate-or-heavy-sleet-showers' => 'Pancadas de granizo moderadas ou fortes',
    'weather_sleet' => 'Granizo',
    'weather_wind' => 'Ventania',
    'weather_fog' => 'Neblina',
    'weather_freezing-fog' => 'Nevoeiro gelado',
    'weather_mist' => 'Neblina',
    'weather_blizzard' => 'Nevasca',
    'weather_overcast' => 'Nublado',
    'weather_cloudy' => 'Nublado',
    'weather_partly-cloudy-day' => 'Parcialmente nublado',
    'weather_partly-cloudy-night' => 'Parcialmente nublada',
    'weather_freezing-drizzle' => 'Garoa congelante',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Granizo',
    'weather_light-showers-of-ice-pellets' => 'Chuva leve de granizo',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Chuva moderada ou pesada de granizo',
    'weather_thundery-outbreaks-possible' => 'Possibilidade de tempestade',
    'weather_patchy-light-rain-with-thunder' => 'Chuva leve e irregular com trovoadas',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Chuva moderada ou forte com trovoadas',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Neve moderada ou forte com trovoadas',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Tempo atual',

    // dav
    'dav_contacts' => 'Contatos',
    'dav_contacts_description' => 'Contatos de :name',
    'dav_birthdays' => 'Aniversários',
    'dav_birthdays_description' => 'Aniversários dos contatos :name\'s',
    'dav_tasks' => 'Tarefas',
    'dav_tasks_description' => 'tarefas de :name',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Contato',
    'contact_list_description' => 'Descrição',

];
