<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2682207 => 'Nhlangano, Shiselweni district',
  2682217 => 'Hlathikulu, Shiselweni district',
  2682227 => 'Hluthi, Shiselweni district',
  2682237 => 'Mahamba, Shiselweni district',
  2682303 => 'Nsoko, Lubombo district',
  2682312 => 'Mhlume, Lubombo district',
  2682313 => 'Mhlume, Lubombo district',
  2682322 => 'Tshaneni, Lubombo district',
  2682323 => 'Tshaneni, Lubombo district',
  2682333 => 'Mpaka, Lubombo district',
  2682343 => 'Siteki, Lubombo district',
  2682344 => 'Siphofaneni, Lubombo district',
  2682363 => 'Big Bend, Lubombo district',
  2682364 => 'Big Bend, Lubombo district',
  2682373 => 'Maphiveni, Lubombo district',
  2682382 => 'Simunye, Lubombo district',
  2682383 => 'Simunye, Lubombo district',
  2682404 => 'Mbabane, Hhohho district',
  2682405 => 'Mbabane, Hhohho district',
  2682406 => 'Mbabane, Hhohho district',
  2682416 => 'Lobamba, Hhohho district',
  2682422 => 'Sidwashini, Hhohho district',
  2682437 => 'Pigg\'s Peak, Hhohho district',
  2682442 => 'Ngwenya, Hhohho district',
  2682452 => 'Bhunya, Hhohho district',
  2682453 => 'Bhunya, Hhohho district',
  2682467 => 'Mhlambanyatsi, Hhohho district',
  2682472 => 'Mahwalala, Hhohho district',
  2682482 => 'Siphocosini, Hhohho district',
  2682505 => 'Manzini',
  2682506 => 'Manzini',
  2682517 => 'Matsapha, Manzini district',
  2682518 => 'Matsapha, Manzini district',
  2682528 => 'Malkerns, Manzini district',
  2682538 => 'Mankayane, Manzini district',
  2682548 => 'Ludzeludze, Manzini district',
  26832 => 'Shiselweni',
  26833 => 'Lubombo',
  26834 => 'Hhohho',
  26835 => 'Manzini',
);
