<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  370310 => 'Varėna',
  370313 => 'Druskininkai',
  370315 => 'Alytus',
  370318 => 'Lazdijai',
  370319 => 'Birštonas/Prienai',
  370340 => 'Ukmergė',
  370342 => 'Vilkaviškis',
  370343 => 'Marijampolė',
  370345 => 'Šakiai',
  370346 => 'Kaišiadorys',
  370347 => 'Kėdainiai',
  370349 => 'Jonava',
  37037 => 'Kaunas',
  370380 => 'Šalčininkai',
  370381 => 'Anykščiai',
  370382 => 'Širvintos',
  370383 => 'Molėtai',
  370385 => 'Zarasai',
  370386 => 'Ignalina/Visaginas',
  370387 => 'Švenčionys',
  370389 => 'Utena',
  37041 => 'Šiauliai',
  370421 => 'Pakruojis',
  370422 => 'Radviliškis',
  370425 => 'Akmenė',
  370426 => 'Joniškis',
  370427 => 'Kelmė',
  370428 => 'Raseiniai',
  370440 => 'Skuodas',
  370441 => 'Šilutė',
  370443 => 'Mažeikiai',
  370444 => 'Telšiai',
  370445 => 'Kretinga',
  370446 => 'Tauragė',
  370447 => 'Jurbarkas',
  370448 => 'Plungė',
  370449 => 'Šilalė',
  37045 => 'Panevėžys',
  370450 => 'Biržai',
  370451 => 'Pasvalys',
  370458 => 'Rokiškis',
  370459 => 'Kupiškis',
  37046 => 'Klaipėda',
  370460 => 'Palanga',
  370469 => 'Neringa',
  370520 => 'Vilnius',
  370521 => 'Vilnius',
  370522 => 'Vilnius',
  370523 => 'Vilnius',
  370524 => 'Vilnius',
  370525 => 'Vilnius',
  370526 => 'Vilnius',
  370527 => 'Vilnius',
  370528 => 'Trakai',
);
