<?php
namespace Aws\ManagedBlockchainQuery\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Managed Blockchain Query** service.
 */
class ManagedBlockchainQueryException extends AwsException {}
