<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'Desear feliz cumpleaños a',
    'type_phone_call' => 'Llamar a',
    'type_lunch' => 'Comer con',
    'type_hangout' => 'Salir con',
    'type_email' => 'Email',
    'type_birthday_kid' => 'Desea feliz cumpleaños al hijo de',
];
