<?php
namespace Aws\HealthLake\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon HealthLake** service.
 */
class HealthLakeException extends AwsException {}
