<?php
namespace Aws\SavingsPlans\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Savings Plans** service.
 */
class SavingsPlansException extends AwsException {}
