<?php
namespace Aws\CodeStarNotifications\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS CodeStar Notifications** service.
 */
class CodeStarNotificationsException extends AwsException {}
