<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  67021 => 'Manufahi',
  67022 => 'Cova Lima',
  67023 => 'Bobonaro',
  67024 => 'Ainaro',
  67025 => 'Dekuse',
  67031 => 'Dili',
  67032 => 'Dili',
  67033 => 'Dili',
  67036 => 'Liquica',
  67037 => 'Aileu',
  67038 => 'Ermera',
  67039 => 'Oekusi',
  67041 => 'Baucau',
  67042 => 'Manatuto',
  67043 => 'Viqueque',
  67044 => 'Lautem',
);
