<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    // contact creation
    'contact_log_contact_created' => 'Kontakt erstellt.',
    'settings_log_contact_created_with_name' => ':name als Kontakt hinzugefügt.',

    // contat description update
    'contact_log_contact_description_updated' => 'Beschreibung aktualisiert.',
    'settings_log_contact_description_updated_with_name' => ':name wurde aktualisiert.',

    // contact description clear
    'contact_log_contact_description_cleared' => 'Beschreibung gelöscht.',
    'settings_log_contact_description_cleared_with_name' => 'Beschreibung von :name gelöscht.',

    // contact work information update
    'contact_log_contact_work_updated' => 'Arbeitsinformationen aktualisiert.',
    'settings_log_contact_work_updated_with_name' => 'Arbeitsinformationen von :name aktualisiert.',

    // company created
    'settings_log_company_created' => 'Firma :name erstellt.',
];
