<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'title' => 'Productwijzigingen',
    'note' => 'Opmerking: Helaas, deze pagina is alleen beschikbaar in het Engels.',
];
