<?php

return array(

    'home' => 'Home',
    'family' => array(
            'father' => 'Dad',
            'mother' => 'Mom',
            'children' => array(
                 'son' => 'Son',
            ),
    ),
    'plural' => 'one apple|a million apples',
    'random' => 'gm8ft2hrrlq1u6m54we9udi',
);
