<?php
namespace Aws\Rekognition\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Rekognition** service.
 */
class RekognitionException extends AwsException {}
