<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hur var din dag? Du kan betygsätta den en gång om dagen.',
    'journal_come_back' => 'Tack. Kom tillbaka imorgon för att betygsätta din dag igen.',
    'journal_description' => 'Obs: tidskriften listar både manuella journalposter och automatiska poster som Aktiviteter gjorda med dina kontakter. Medan du kan ta bort journalposter manuellt, måste du ta bort aktiviteten direkt på kontaktsidan.',
    'journal_add' => 'Lägg till en journalpost',
    'journal_edit' => 'Redigera en journalpost',
    'journal_empty' => 'Tom journal',
    'journal_created_at' => 'Created at {date}',
    'journal_created_automatically' => 'Skapad automatiskt',
    'journal_entry_type_journal' => 'Journalpost',
    'journal_entry_type_activity' => 'Aktivitet',
    'journal_entry_rate' => 'Du betygsatte din dag.',
    'journal_add_comment' => 'Vill du lägga till en kommentar (valfritt)?',
    'journal_show_comment' => 'Visa kommentar',
    'entry_delete_success' => 'Journalposten har tagits bort.',
    'journal_add_title' => 'Titel (valfritt)',
    'journal_add_date' => 'Datum',
    'journal_add_post' => 'Inlägg',
    'journal_add_cta' => 'Spara',
    'journal_blank_cta' => 'Lägg till din första journalpost',
    'journal_blank_description' => 'Tidskriften låter dig skriva händelser som hände dig, och kom ihåg dem.',
    'delete_confirmation' => 'Är du säker på att du vill ta bort denna journalpost?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
