<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  492203 => 'Köln-Porz',
  49221 => 'Köln',
  492339 => 'Sprockhövel-Haßlinghausen',
  4934445 => 'Stößen',
  4934493 => 'Gößnitz Thüringen',
  4934901 => 'Roßlau Elbe',
  4935240 => 'Tauscha bei Großenhain',
  4935248 => 'Schönfeld bei Großenhain',
  4935726 => 'Groß Särchen',
  4935753 => 'Großräschen',
  4935841 => 'Großschönau Sachsen',
  4935938 => 'Großpostwitz OL',
  4935952 => 'Großröhrsdorf OL',
  4936072 => 'Weißenborn-Lüderode',
  493647 => 'Pößneck',
  4936484 => 'Knau bei Pößneck',
  4936705 => 'Oberweißbach Thüringer Wald',
  4936949 => 'Obermaßfeld-Grimmenthal',
  4938234 => 'Born Darß',
  4939883 => 'Groß Dölln',
  4939934 => 'Groß Plasten',
  4939976 => 'Groß Bützin',
  494483 => 'Ovelgönne-Großenmeer',
  494497 => 'Barßel-Harkebrügge',
  494509 => 'Groß Grönau',
  494684 => 'Langeneß Hallig',
  495053 => 'Faßberg-Müden',
  495064 => 'Groß Düngen',
  495384 => 'Seesen-Groß Rhüden',
  495827 => 'Unterlüß',
  496252 => 'Heppenheim Bergstraße',
  496321 => 'Neustadt an der Weinstraße',
  496364 => 'Nußbach Pfalz',
  496663 => 'Steinau an der Straße',
  497162 => 'Süßen',
  497351 => 'Biberach an der Riß',
  497355 => 'Hochdorf Riß',
  498170 => 'Straßlach-Dingharting',
  498367 => 'Roßhaupten Forggensee',
  498536 => 'Kößlarn',
  498633 => 'Tüßling',
  498807 => 'Dießen am Ammersee',
  4989 => 'München',
  49911 => 'Nürnberg',
  499141 => 'Weißenburg in Bayern',
  499242 => 'Gößweinstein',
  499567 => 'Seßlach-Gemünda',
  499636 => 'Plößberg',
  499656 => 'Moosbach bei Vohenstrauß',
);
