<?php
namespace Aws\SsmSap\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Systems Manager for SAP** service.
 */
class SsmSapException extends AwsException {}
