<?php

return array(

    'home' => 'Inicio',
    'family' => array(
            'father' => 'Padre',
            'mother' => 'Madre',
            'children' => array(
                 'son' => 'Hijo',
            ),
    ),
    'messagePlural' => 'Una manzana|Muchas manzanas'
);
