<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ja',
    'no' => 'Nein',
    'update' => 'Aktualisieren',
    'save' => 'Speichern',
    'add' => 'Hinzufügen',
    'cancel' => 'Abbrechen',
    'confirm' => 'Bestätigen',
    'delete_confirm' => 'Bist du dir sicher?',
    'delete' => 'Löschen',
    'edit' => 'Bearbeiten',
    'upload' => 'Hochladen',
    'download' => 'Herunterladen',
    'save_close' => 'Speichern und schließen',
    'close' => 'Schließen',
    'copy' => 'kopieren',
    'create' => 'Erstellen',
    'remove' => 'Entfernen',
    'revoke' => 'Aufheben',
    'done' => 'Fertig',
    'back' => 'Zurück',
    'verify' => 'Überprüfe',
    'new' => 'Neu',
    'unknown' => 'Ich weiß es nicht',
    'load_more' => 'Lade mehr',
    'loading' => 'Lädt…',
    'with' => 'mit',
    'today' => 'heute',
    'yesterday' => 'gestern',
    'another_day' => 'anderen Tag',
    'date' => 'Datum',
    'type' => 'Typ',
    'zoom' => 'vergrößern',
    'upgrade' => 'Zum Freischalten aktualisieren',
    'percent_uploaded' => '{percent}% hochgeladen',
    'retry' => 'Wiederholen',
    'filter' => 'Liste filtern',
    'go_back' => 'Zurück',
    'file_selected' => 'Eine Datei ausgewählt…|{count} Dateien ausgewählt…',

    'application_title' => 'Monica – persönlicher Beziehungsmanager',
    'application_description' => 'Monica ist ein Werkzeug, um Ihre Interaktionen mit Ihren Lieben, Freunden und Familie zu verwalten.',
    'application_og_title' => 'Bessere Beziehungen zu deinen Liebsten. Kostenloses Online CRM für Freunde und Familie.',

    'markdown_description' => 'Du möchtest deinen Text schöner formatieren? Monica unterstützt Markdown.',
    'markdown_link' => 'Öffne die Dokumentation',

    'header_settings_link' => 'Einstellungen',
    'header_logout_link' => 'Ausloggen',
    'header_changelog_link' => 'Produktänderungen',

    'main_nav_cta' => 'Person hinzufügen',
    'main_nav_dashboard' => 'Dashboard',
    'main_nav_family' => 'Personen',
    'main_nav_journal' => 'Tagebuch',
    'main_nav_activities' => 'Aktivitäten',
    'main_nav_tasks' => 'Aufgaben',

    'footer_remarks' => 'Anmerkungen?',
    'footer_send_email' => 'Schreib uns eine E-Mail',
    'footer_privacy' => 'Datenschutzrichtlinie',
    'footer_release' => 'Versionshinweise',
    'footer_newsletter' => 'Newsletter',
    'footer_source_code' => 'Monica bei GitHub',
    'footer_version' => 'Version: :version',
    'footer_new_version' => 'Eine neue Version von Monica ist verfügbar',

    'footer_modal_version_whats_new' => 'Was gibt\'s Neues',
    'footer_modal_version_release_away' => 'Du bist ein Release hinter der neuesten verfügbaren Version. Du solltest deine Installation updaten.|Du bist :number Releases hinter der neuesten verfügbaren Version. Du solltest deine Installation updaten.',

    'breadcrumb_dashboard' => 'Dashboard',
    'breadcrumb_list_contacts' => 'Kontaktliste',
    'breadcrumb_archived_contacts' => 'Gespeicherte Kontakte',
    'breadcrumb_journal' => 'Tagebuch',
    'breadcrumb_settings' => 'Einstellungen',
    'breadcrumb_settings_export' => 'Export',
    'breadcrumb_settings_users' => 'Benutzer',
    'breadcrumb_settings_users_add' => 'Benutzer hinzufügen',
    'breadcrumb_settings_subscriptions' => 'Abonnement',
    'breadcrumb_settings_import' => 'Import',
    'breadcrumb_settings_import_report' => 'Import-Bericht',
    'breadcrumb_settings_import_upload' => 'Hochladen',
    'breadcrumb_settings_tags' => 'Markierungen',
    'breadcrumb_add_significant_other' => 'Lebensgefährte hinzufügen',
    'breadcrumb_edit_significant_other' => 'Lebensgefährte bearbeiten',
    'breadcrumb_add_note' => 'Notiz hinzufügen',
    'breadcrumb_edit_note' => 'Notiz bearbeiten',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV-Ressourcen',
    'breadcrumb_edit_introductions' => 'Wie habt ihr euch getroffen',
    'breadcrumb_settings_personalization' => 'Personalisierung',
    'breadcrumb_settings_security' => 'Sicherheit',
    'breadcrumb_settings_security_2fa' => 'Zwei-Faktor-Authentifizierung',
    'breadcrumb_profile' => 'Profil von :name',

    'gender_male' => 'Männlich',
    'gender_female' => 'Weiblich',
    'gender_none' => 'Möchte ich nicht angeben',
    'gender_no_gender' => 'Kein Geschlecht',

    'error_title' => 'Whoops! Da lief etwas falsch.',
    'error_unauthorized' => 'Du darfst das leider nicht, da du nicht angemeldet bist.',
    'error_user_account' => 'Dieser Benutzer gehört nicht zum angegebenen Konto.',
    'error_save' => 'Beim Versuch die Daten zu speichern ist ein Fehler aufgetreten.',
    'error_try_again' => 'Etwas ist schiefgegangen. Bitte versuche es noch mal.',
    'error_id' => 'Fehler Nr: :id',
    'error_unavailable' => 'Dienst nicht verfügbar',
    'error_maintenance' => 'Wartungsarbeiten im Gange. Wir sind gleich wieder für dich da.',
    'error_help' => 'Wir sind gleich wieder da.',
    'error_twitter' => 'Folgen Sie <a href="https://twitter.com/:twitter"> uns auf Twitter</a> um informiert zu werden, wenn es weitergeht.',
    'error_no_term' => 'Für diese Instanz gibt es noch keine Richtlinie.',

    'default_save_success' => 'Die Daten wurden gespeichert.',

    'compliance_title' => 'Entschuldige die Unterbrechung.',
    'compliance_desc' => 'Wir haben unsere <a href=":urlterm" hreflang=":hreflang">AGBs</a> und <a href=":url" hreflang=":hreflang">Datenschutzerklärung</a> geändert. Wir sind gesetzlich dazu verpflichtet zu verlangen, dass du beides durchliest und akzeptierst, damit du deinen Account weiter nutzen kannst.',
    'compliance_desc_end' => 'Wir machen nichts Böses mit deinen Daten oder deinem Account und werden das auch nie tun.',
    'compliance_terms' => 'Neue AGB und Datenschutzerklärung akzeptieren',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Liebesbeziehungen',
    'relationship_type_group_family' => 'Familienverhältnisse',
    'relationship_type_group_friend' => 'Freundschaftsbeziehungen',
    'relationship_type_group_work' => 'Arbeitsverhältnisse',
    'relationship_type_group_other' => 'Andere Art von Beziehungen',

    'relationship_type_partner' => 'Lebensgefährte',
    'relationship_type_partner_female' => 'Lebensgefährtin',
    'relationship_type_partner_male' => 'Lebensgefährte',
    'relationship_type_partner_with_name' => ':names Lebensgefährte',
    'relationship_type_partner_female_with_name' => ':names Lebensgefährtin',
    'relationship_type_partner_male_with_name' => ':name’s Lebensgefährte',

    'relationship_type_spouse' => 'Ehegatte',
    'relationship_type_spouse_female' => 'Ehefrau',
    'relationship_type_spouse_male' => 'Ehemann',
    'relationship_type_spouse_with_name' => ':names Ehegatten',
    'relationship_type_spouse_female_with_name' => ':name’s Ehefrau',
    'relationship_type_spouse_male_with_name' => ':name’s Ehemann',

    'relationship_type_date' => 'Verabredung',
    'relationship_type_date_female' => 'Verabredung',
    'relationship_type_date_male' => 'Verabredung',
    'relationship_type_date_with_name' => ':names Verabredung',
    'relationship_type_date_female_with_name' => ':names Verabredung',
    'relationship_type_date_male_with_name' => ':name’s Verabredung',

    'relationship_type_lover' => 'Liebhaber',
    'relationship_type_lover_female' => 'Liebhaberin',
    'relationship_type_lover_male' => 'Liebhaber',
    'relationship_type_lover_with_name' => ':names Liebhaber',
    'relationship_type_lover_female_with_name' => ':names Liebhaberin',
    'relationship_type_lover_male_with_name' => ':name’s Liebhaber',

    'relationship_type_inlovewith' => 'verliebt in',
    'relationship_type_inlovewith_female' => 'verliebt in',
    'relationship_type_inlovewith_male' => 'verliebt in',
    'relationship_type_inlovewith_with_name' => ':name ist verliebt in',
    'relationship_type_inlovewith_female_with_name' => ':name ist verliebt in',
    'relationship_type_inlovewith_male_with_name' => ':name ist verliebt in',

    'relationship_type_lovedby' => 'geliebt von',
    'relationship_type_lovedby_female' => 'geliebt von',
    'relationship_type_lovedby_male' => 'geliebt von',
    'relationship_type_lovedby_with_name' => ':names heimlicher Verehrer',
    'relationship_type_lovedby_female_with_name' => ':names heimliche Verehrerin',
    'relationship_type_lovedby_male_with_name' => ':name’s heimlicher Verehrer',

    'relationship_type_ex' => 'Ex-Partner',
    'relationship_type_ex_female' => 'Ex-Freundin',
    'relationship_type_ex_male' => 'Ex-Freund',
    'relationship_type_ex_with_name' => ':name’s Ex-Partner',
    'relationship_type_ex_female_with_name' => ':name\'s Ex-Freundin',
    'relationship_type_ex_male_with_name' => ':name’s Ex-Freund',

    'relationship_type_parent' => 'Elternteil',
    'relationship_type_parent_female' => 'Mutter',
    'relationship_type_parent_male' => 'Vater',
    'relationship_type_parent_with_name' => ':name’s Elternteil',
    'relationship_type_parent_female_with_name' => ':name\'s Mutter',
    'relationship_type_parent_male_with_name' => ':name’s Vater',

    'relationship_type_child' => 'Kind',
    'relationship_type_child_female' => 'Tochter',
    'relationship_type_child_male' => 'Sohn',
    'relationship_type_child_with_name' => ':name’s Kind',
    'relationship_type_child_female_with_name' => ':names Tochter',
    'relationship_type_child_male_with_name' => ':name’s Sohn',

    'relationship_type_stepparent' => 'Stiefelternteil',
    'relationship_type_stepparent_female' => 'Stiefmutter',
    'relationship_type_stepparent_male' => 'Stiefvater',
    'relationship_type_stepparent_with_name' => ':name’s Stiefelternteil',
    'relationship_type_stepparent_female_with_name' => ':name\'s Stiefmutter',
    'relationship_type_stepparent_male_with_name' => ':name’s Stiefvater',

    'relationship_type_stepchild' => 'Stiefkind',
    'relationship_type_stepchild_female' => 'Stieftochter',
    'relationship_type_stepchild_male' => 'Stiefsohn',
    'relationship_type_stepchild_with_name' => ':name’s Stiefkind',
    'relationship_type_stepchild_female_with_name' => ':names Stieftochter',
    'relationship_type_stepchild_male_with_name' => ':name’s Stiefsohn',

    'relationship_type_sibling' => 'Geschwister',
    'relationship_type_sibling_female' => 'Schwester',
    'relationship_type_sibling_male' => 'Bruder',
    'relationship_type_sibling_with_name' => ':name’s Geschwister',
    'relationship_type_sibling_female_with_name' => ':names Schwester',
    'relationship_type_sibling_male_with_name' => ':name’s Bruder',

    'relationship_type_grandparent' => 'Großelternteil',
    'relationship_type_grandparent_female' => 'Oma',
    'relationship_type_grandparent_male' => 'Opa',
    'relationship_type_grandparent_with_name' => ':name’s Großelternteil',
    'relationship_type_grandparent_female_with_name' => ':name’s Großmutter',
    'relationship_type_grandparent_male_with_name' => ':name’s Großvater',

    'relationship_type_grandchild' => 'Enkelkind',
    'relationship_type_grandchild_female' => 'Enkelin',
    'relationship_type_grandchild_male' => 'Enkel',
    'relationship_type_grandchild_with_name' => ':name’s Enkelkind',
    'relationship_type_grandchild_female_with_name' => ':name’s Enkelin',
    'relationship_type_grandchild_male_with_name' => ':name’s Enkel',

    'relationship_type_uncle' => 'Onkel',
    'relationship_type_uncle_female' => 'Tante',
    'relationship_type_uncle_male' => 'Onkel',
    'relationship_type_uncle_with_name' => ':name\'s Onkel',
    'relationship_type_uncle_female_with_name' => ':name\'s Tante',
    'relationship_type_uncle_male_with_name' => ':name’s Onkel',

    'relationship_type_nephew' => 'Neffe',
    'relationship_type_nephew_female' => 'Nichte',
    'relationship_type_nephew_male' => 'Neffe',
    'relationship_type_nephew_with_name' => ':name\'s Neffe',
    'relationship_type_nephew_female_with_name' => ':name\'s Nichte',
    'relationship_type_nephew_male_with_name' => ':name’s Neffe',

    'relationship_type_cousin' => 'Cousin',
    'relationship_type_cousin_female' => 'Cousine',
    'relationship_type_cousin_male' => 'Cousin',
    'relationship_type_cousin_with_name' => ':name\'s Cousin',
    'relationship_type_cousin_female_with_name' => ':name\'s Cousine',
    'relationship_type_cousin_male_with_name' => ':name’s Cousin',

    'relationship_type_godfather' => 'Pate',
    'relationship_type_godfather_female' => 'Patin',
    'relationship_type_godfather_male' => 'Patenonkel',
    'relationship_type_godfather_with_name' => ':name’s Pate',
    'relationship_type_godfather_female_with_name' => ':names Patin',
    'relationship_type_godfather_male_with_name' => ':name’s Patenonkel',

    'relationship_type_godson' => 'Patenkind',
    'relationship_type_godson_female' => 'Patenkind',
    'relationship_type_godson_male' => 'Patensohn',
    'relationship_type_godson_with_name' => ':name’s Patenkind',
    'relationship_type_godson_female_with_name' => ':name\'s Patenkind',
    'relationship_type_godson_male_with_name' => ':name’s Patensohn',

    'relationship_type_friend' => 'Freund',
    'relationship_type_friend_female' => 'Freundin',
    'relationship_type_friend_male' => 'Freund',
    'relationship_type_friend_with_name' => ':name\'s Freund',
    'relationship_type_friend_female_with_name' => ':name\'s Freundin',
    'relationship_type_friend_male_with_name' => ':name’s Freund',

    'relationship_type_bestfriend' => 'Bester Freund',
    'relationship_type_bestfriend_female' => 'Beste Freundin',
    'relationship_type_bestfriend_male' => 'bester Freund',
    'relationship_type_bestfriend_with_name' => ':name\'s bester Freund',
    'relationship_type_bestfriend_female_with_name' => ':name\'s beste Freundin',
    'relationship_type_bestfriend_male_with_name' => ':name’s bester Freund',

    'relationship_type_colleague' => 'Kollege',
    'relationship_type_colleague_female' => 'Kollegin',
    'relationship_type_colleague_male' => 'Kollege',
    'relationship_type_colleague_with_name' => ':name\'s Kollege',
    'relationship_type_colleague_female_with_name' => ':name\'s Kollegin',
    'relationship_type_colleague_male_with_name' => ':name’s Kollege',

    'relationship_type_boss' => 'Chef',
    'relationship_type_boss_female' => 'Chefin',
    'relationship_type_boss_male' => 'Chef',
    'relationship_type_boss_with_name' => ':name\'s Chef',
    'relationship_type_boss_female_with_name' => ':name\'s Chefin',
    'relationship_type_boss_male_with_name' => ':name’s Chef',

    'relationship_type_subordinate' => ':name\'s Untergebener',
    'relationship_type_subordinate_female' => ':name\'s Untergebene',
    'relationship_type_subordinate_male' => 'Untergebener',
    'relationship_type_subordinate_with_name' => ':name\'s Mitarbeiter',
    'relationship_type_subordinate_female_with_name' => ':name\'s Mitarbeiterin',
    'relationship_type_subordinate_male_with_name' => ':name’s Untergebener',

    'relationship_type_mentor' => 'Mentor',
    'relationship_type_mentor_female' => 'Mentorin',
    'relationship_type_mentor_male' => 'Mentor',
    'relationship_type_mentor_with_name' => ':name\'s Mentor',
    'relationship_type_mentor_female_with_name' => ':name\'s Mentorin',
    'relationship_type_mentor_male_with_name' => ':name’s Mentor',

    'relationship_type_protege' => 'Schützling',
    'relationship_type_protege_female' => 'Schützling',
    'relationship_type_protege_male' => 'Schützling',
    'relationship_type_protege_with_name' => ':name’s Schützling',
    'relationship_type_protege_female_with_name' => ':name’s Schützling',
    'relationship_type_protege_male_with_name' => ':name’s Schützling',

    'relationship_type_ex_husband' => 'Ex-Mann',
    'relationship_type_ex_husband_female' => 'Ex-Frau',
    'relationship_type_ex_husband_male' => 'Ex-Frau',
    'relationship_type_ex_husband_with_name' => ':name’s Ex-Mann',
    'relationship_type_ex_husband_female_with_name' => ':name’s Ex-Frau',
    'relationship_type_ex_husband_male_with_name' => ':name’s Ex-Frau',

    // emotions
    'emotion_primary_love' => 'Liebe',
    'emotion_primary_joy' => 'Freude',
    'emotion_primary_surprise' => 'Überraschung',
    'emotion_primary_anger' => 'Zorn',
    'emotion_primary_sadness' => 'Traurigkeit',
    'emotion_primary_fear' => 'Angst',

    'emotion_secondary_affection' => 'Zuneigung',
    'emotion_secondary_lust' => 'Begierde',
    'emotion_secondary_longing' => 'Sehnsucht',
    'emotion_secondary_cheerfulness' => 'Fröhlich',
    'emotion_secondary_zest' => 'Elan',
    'emotion_secondary_contentment' => 'Zufriedenheit',
    'emotion_secondary_pride' => 'Stolz',
    'emotion_secondary_optimism' => 'Optimismus',
    'emotion_secondary_enthrallment' => 'Begeisterung',
    'emotion_secondary_relief' => 'Erleichterung',
    'emotion_secondary_surprise' => 'Überraschung',
    'emotion_secondary_irritation' => 'Irritation',
    'emotion_secondary_exasperation' => 'Verzweiflung',
    'emotion_secondary_rage' => 'Wut',
    'emotion_secondary_disgust' => 'Ekel',
    'emotion_secondary_envy' => 'Neid',
    'emotion_secondary_suffering' => 'Leiden',
    'emotion_secondary_sadness' => 'Traurigkeit',
    'emotion_secondary_disappointment' => 'Enttäuscht',
    'emotion_secondary_shame' => 'Scham',
    'emotion_secondary_neglect' => 'Vernachlässigung',
    'emotion_secondary_sympathy' => 'Sympathie',
    'emotion_secondary_horror' => 'Entsetzen',
    'emotion_secondary_nervousness' => 'Nervosität',

    'emotion_adoration' => 'Verehrung',
    'emotion_affection' => 'Zuneigung',
    'emotion_love' => 'Liebe',
    'emotion_fondness' => 'Zuneigung',
    'emotion_liking' => 'Gefallen',
    'emotion_attraction' => 'Anziehung',
    'emotion_caring' => 'Fürsorglich',
    'emotion_tenderness' => 'Zärtlichkeit',
    'emotion_compassion' => 'Mitgefühl',
    'emotion_sentimentality' => 'Sentimentalität',
    'emotion_arousal' => 'Erregung',
    'emotion_desire' => 'Verlangen',
    'emotion_lust' => 'Begierde',
    'emotion_passion' => 'Leidenschaft',
    'emotion_infatuation' => 'Betörung',
    'emotion_longing' => 'Sehnsucht',
    'emotion_amusement' => 'Vergnügen',
    'emotion_bliss' => 'Glück',
    'emotion_cheerfulness' => 'Fröhlichkeit',
    'emotion_gaiety' => 'Heiterkeit',
    'emotion_glee' => 'Freude',
    'emotion_jolliness' => 'Fröhlichkeit',
    'emotion_joviality' => 'Herzlichkeit',
    'emotion_joy' => 'Freude',
    'emotion_delight' => 'Freude',
    'emotion_enjoyment' => 'Genuss',
    'emotion_gladness' => 'Freude',
    'emotion_happiness' => 'Glück',
    'emotion_jubilation' => 'Jubel',
    'emotion_elation' => 'Hochgefühl',
    'emotion_satisfaction' => 'Zufriedenheit',
    'emotion_ecstasy' => 'Ecstasy',
    'emotion_euphoria' => 'Euphorie',
    'emotion_enthusiasm' => 'Begeisterung',
    'emotion_zeal' => 'Eifer',
    'emotion_zest' => 'Elan',
    'emotion_excitement' => 'Aufregung',
    'emotion_thrill' => 'Nervenkitzel',
    'emotion_exhilaration' => 'Heiterkeit',
    'emotion_contentment' => 'Zufriedenheit',
    'emotion_pleasure' => 'Vergnügen',
    'emotion_pride' => 'Stolz',
    'emotion_eagerness' => 'Verlangen',
    'emotion_hope' => 'Hoffnung',
    'emotion_optimism' => 'Optimismus',
    'emotion_enthrallment' => 'Begeisterung',
    'emotion_rapture' => 'Entrückung',
    'emotion_relief' => 'Erleichterung',
    'emotion_amazement' => 'Verwunderung',
    'emotion_surprise' => 'Überraschung',
    'emotion_astonishment' => 'Erstaunen',
    'emotion_aggravation' => 'Verärgerung',
    'emotion_irritation' => 'Irritation',
    'emotion_agitation' => 'Erregt',
    'emotion_annoyance' => 'Verärgerung',
    'emotion_grouchiness' => 'Miesepetrigkeit',
    'emotion_grumpiness' => 'Mür­risch­keit',
    'emotion_exasperation' => 'Verzweiflung',
    'emotion_frustration' => 'Frustration',
    'emotion_anger' => 'Zorn',
    'emotion_rage' => 'Wut',
    'emotion_outrage' => 'Entrüstung',
    'emotion_fury' => 'Rage',
    'emotion_wrath' => 'Zorn',
    'emotion_hostility' => 'Feindseligkeit',
    'emotion_ferocity' => 'Wildheit',
    'emotion_bitterness' => 'Bitterkeit',
    'emotion_hate' => 'Hass',
    'emotion_loathing' => 'Abscheu',
    'emotion_scorn' => 'Verachtung',
    'emotion_spite' => 'Boshaftigkeit',
    'emotion_vengefulness' => 'Rachsucht',
    'emotion_dislike' => 'Abneigung',
    'emotion_resentment' => 'Missgunst',
    'emotion_disgust' => 'Ekel',
    'emotion_revulsion' => 'Abscheu',
    'emotion_contempt' => 'Verachtung',
    'emotion_envy' => 'Neid',
    'emotion_jealousy' => 'Eifersucht',
    'emotion_agony' => 'Pein',
    'emotion_suffering' => 'Leid',
    'emotion_hurt' => 'Schmerz',
    'emotion_anguish' => 'Qual',
    'emotion_depression' => 'Depression',
    'emotion_despair' => 'Verzweiflung',
    'emotion_hopelessness' => 'Hoffnungslosigkeit',
    'emotion_gloom' => 'Trübsinn',
    'emotion_glumness' => 'Verdrießlich',
    'emotion_sadness' => 'Traurigkeit',
    'emotion_unhappiness' => 'Unglücklichkeit',
    'emotion_grief' => 'Trauer',
    'emotion_sorrow' => 'Bedauern',
    'emotion_woe' => 'Kummer',
    'emotion_misery' => 'Elend',
    'emotion_melancholy' => 'Melancholie',
    'emotion_dismay' => 'Bestürzung',
    'emotion_disappointment' => 'Enttäuschung',
    'emotion_displeasure' => 'Missfallen',
    'emotion_guilt' => 'Schuld',
    'emotion_shame' => 'Scham',
    'emotion_regret' => 'Bedauern',
    'emotion_remorse' => 'Reue',
    'emotion_alienation' => 'Entfremdung',
    'emotion_isolation' => 'Ausgrenzung',
    'emotion_neglect' => 'Vernachlässigung',
    'emotion_loneliness' => 'Einsamkeit',
    'emotion_rejection' => 'Zurückweisung',
    'emotion_homesickness' => 'Heimweh',
    'emotion_defeat' => 'Versagen',
    'emotion_dejection' => 'Niedergeschlagenheit',
    'emotion_insecurity' => 'Unsicherheit',
    'emotion_embarrassment' => 'Peinlichkeit',
    'emotion_humiliation' => 'Demütigung',
    'emotion_insult' => 'Beleidigung',
    'emotion_pity' => 'Mitleid',
    'emotion_sympathy' => 'Sympathie',
    'emotion_alarm' => 'Sorge',
    'emotion_shock' => 'Schock',
    'emotion_fear' => 'Angst',
    'emotion_fright' => 'Furcht',
    'emotion_horror' => 'Entsetzen',
    'emotion_terror' => 'Grauen',
    'emotion_panic' => 'Panik',
    'emotion_hysteria' => 'Hysterie',
    'emotion_mortification' => 'Kränkung',
    'emotion_anxiety' => 'Beklommenheit',
    'emotion_nervousness' => 'Nervosität',
    'emotion_tenseness' => 'Anspannung',
    'emotion_uneasiness' => 'Unbehagen',
    'emotion_apprehension' => 'Befürchtung',
    'emotion_worry' => 'Besorgnis',
    'emotion_distress' => 'Belastung',
    'emotion_dread' => 'Grauen',

    // weather
    'weather_sunny' => 'Sonnig',
    'weather_clear' => 'Klar',
    'weather_clear-day' => 'Klar',
    'weather_clear-night' => 'Klare Nacht',
    'weather_light-drizzle' => 'Leichter Nieselregen',
    'weather_patchy-light-drizzle' => 'Vereinzelt leichter Nieselregen',
    'weather_patchy-light-rain' => 'Stellenweise leichter Regen',
    'weather_light-rain' => 'Leichter Regen',
    'weather_moderate-rain-at-times' => 'Gelegentlich mäßiger Regen',
    'weather_moderate-rain' => 'Mäßiger Regen',
    'weather_patchy-rain-possible' => 'Stellenweise Regen möglich',
    'weather_heavy-rain-at-times' => 'Gelegentlich starker Regen',
    'weather_heavy-rain' => 'Starker Regen',
    'weather_light-freezing-rain' => 'Leichter gefrierender Regen',
    'weather_moderate-or-heavy-freezing-rain' => 'Mäßiger bis starker gefrierender Regen',
    'weather_light-sleet' => 'Leichter Schneeregen',
    'weather_moderate-or-heavy-rain-shower' => 'Mäßige bis starke Regenschauer',
    'weather_light-rain-shower' => 'Leichte Regenschauer',
    'weather_torrential-rain-shower' => 'Starkregenschauer',
    'weather_rain' => 'Regen',
    'weather_snow' => 'Schnee',
    'weather_blowing-snow' => 'Schneegestöber',
    'weather_patchy-light-snow' => 'Vereinzelt leichter Schneefall',
    'weather_light-snow' => 'Leichter Schneefall',
    'weather_patchy-moderate-snow' => 'Stellenweise mäßiger Schneefall',
    'weather_moderate-snow' => 'Mäßiger Schneefall',
    'weather_patchy-heavy-snow' => 'Vereinzelt starker Schneefall',
    'weather_heavy-snow' => 'Starker Schneefall',
    'weather_light-snow-showers' => 'Leichter Schneeschauer',
    'weather_moderate-or-heavy-snow-showers' => 'Mäßige bis starke Schneeschauer',
    'weather_patchy-snow-possible' => 'Stellenweiser Schneefall möglich',
    'weather_patchy-sleet-possible' => 'Stellenweiser Schneeregen möglich',
    'weather_moderate-or-heavy-sleet' => 'Mäßiger bis starker Schneeregen',
    'weather_light-sleet-showers' => 'Leichte Schneeregenschauer',
    'weather_moderate-or-heavy-sleet-showers' => 'Mäßige bis starke Schneeregenschauer',
    'weather_sleet' => 'Schneeregen',
    'weather_wind' => 'Wind',
    'weather_fog' => 'Nebel',
    'weather_freezing-fog' => 'Gefrierender Nebel',
    'weather_mist' => 'Nebel',
    'weather_blizzard' => 'Schneesturm',
    'weather_overcast' => 'Bewölkt',
    'weather_cloudy' => 'Bewölkt',
    'weather_partly-cloudy-day' => 'Teilweise bewölkt',
    'weather_partly-cloudy-night' => 'Teilweise bewölkt',
    'weather_freezing-drizzle' => 'Gefrierender Nieselregen',
    'weather_heavy-freezing-drizzle' => 'Starker gefrierender Nieselregen',
    'weather_patchy-freezing-drizzle-possible' => 'Stellenweise gefrierender Nieselregen möglich',
    'weather_ice-pellets' => 'Graupel',
    'weather_light-showers-of-ice-pellets' => 'Leichte Graupelschauer',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Mäßige bis starke Graupelschauer',
    'weather_thundery-outbreaks-possible' => 'Gewitterausbrüche möglich',
    'weather_patchy-light-rain-with-thunder' => 'Stellenweise leichter Regen bei Gewitter',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Mäßiger bis starker Regen bei Gewitter',
    'weather_patchy-light-snow-with-thunder' => 'Stellenweise leichter Schneefall bei Gewitter',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Mäßiger bis starker Schneefall bei Gewitter',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Aktuelles Wetter',

    // dav
    'dav_contacts' => 'Kontakte',
    'dav_contacts_description' => 'Kontakte von :name',
    'dav_birthdays' => 'Geburtstage',
    'dav_birthdays_description' => 'Geburtstage der Kontakte von :name',
    'dav_tasks' => 'Aufgaben',
    'dav_tasks_description' => ':names Aufgaben',

    // contact list
    'contact_list_avatar' => 'Profilbild',
    'contact_list_name' => 'Kontakt',
    'contact_list_description' => 'Beschreibung',

];
