<?php
namespace Aws\DataZone\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon DataZone** service.
 */
class DataZoneException extends AwsException {}
