<?php
// This file was auto-generated from sdk-root/src/data/sqs/2012-11-05/paginators-1.json
return [ 'pagination' => [ 'ListDeadLetterSourceQueues' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'queueUrls', ], 'ListQueues' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'QueueUrls', ], ],];
