<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => '欢迎登录账号',
    'dashboard_blank_description' => 'Monica是一个记录你所有关心的人及与其交互信息的地方',
    'dashboard_blank_cta' => '添加您的第一个联系人',
    'dashboard_blank_illustration' => '插画： <a href=":url">Freepik</a>',

    'notes_title' => '您还没有任何便签。',

    'tab_recent_calls' => '最近通话',
    'tab_favorite_notes' => '收藏便签',
    'tab_calls_blank' => '您还没有电话拨打记录。',
    'tab_debts' => '债务',
    'tab_debts_blank' => '您还没有添加债务信息。',
    'tab_tasks' => '任务',
    'tab_tasks_blank' => '你还没有任何任务',

    'tasks_add_task_placeholder' => '这个任务是关于什么的？',
    'tasks_tab_your_contacts' => '与任务相关的联系人',
    'tasks_tab_your_tasks' => '您的任务',
    'tasks_add_note' => '按<kbd>回车</kbd>来添加任务',
    'task_add_cta' => '添加任务',

    'debts_you_owe' => '待还金额',

    'statistics_contacts' => '联系人',
    'statistics_activities' => '活动',
    'statistics_gifts' => '礼物',

    'reminders_next_months' => '近三个月的活动',
    'reminders_none' => '本月尚无提醒事项.',

    'product_changes' => '更新日志',
    'product_view_details' => '查看详情',
];
