<?php
namespace Aws\ApiGatewayManagementApi\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AmazonApiGatewayManagementApi** service.
 */
class ApiGatewayManagementApiException extends AwsException {}
