<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9411 => 'Colombo',
  9421 => 'Jaffna',
  9423 => 'Mannar',
  9424 => 'Vavuniya',
  9425 => 'Anuradhapura',
  9426 => 'Trincomalee',
  9427 => 'Polonnaruwa',
  9431 => 'Negombo, Gampaha',
  9432 => 'Chilaw, Puttalam',
  9433 => 'Gampaha',
  9434 => 'Kalutara',
  9435 => 'Kegalle',
  9436 => 'Avissawella, Colombo',
  9437 => 'Kurunegala',
  9438 => 'Panadura, Kalutara',
  9441 => 'Matara',
  9445 => 'Ratnapura',
  9447 => 'Hambantota',
  9451 => 'Hatton, Nuwara Eliya',
  9452 => 'Nuwara Eliya',
  9454 => 'Nawalapitiya, Kandy',
  9455 => 'Badulla',
  9457 => 'Bandarawela, Badulla',
  9463 => 'Ampara',
  9465 => 'Batticaloa',
  9466 => 'Matale',
  9467 => 'Kalmunai, Ampara',
  9482 => 'Kandy',
  9491 => 'Galle',
);
