<?php
namespace Aws\Synthetics\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Synthetics** service.
 */
class SyntheticsException extends AwsException {}
