<?php
// This file was auto-generated from sdk-root/src/data/scheduler/2021-06-30/paginators-1.json
return [ 'pagination' => [ 'ListScheduleGroups' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ScheduleGroups', ], 'ListSchedules' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Schedules', ], ],];
