<?php
namespace Aws\EventBridge\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon EventBridge** service.
 */
class EventBridgeException extends AwsException {}
