<?php
namespace Aws\Sms\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Server Migration Service** service.
 */
class SmsException extends AwsException {}
