<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AD' => 'Uandora',
  'AF' => 'Ufugustani',
  'AL' => 'Ualbania',
  'AS' => 'Usamoa ya Marekani',
  'AZ' => 'Uazabajani',
  'BI' => 'Urundi',
  'BJ' => 'Ubelin',
  'CA' => 'Ukanada',
  'CG' => 'Ukongo',
  'CH' => 'Uswisi',
  'CI' => 'Ukodiva',
  'CL' => 'Uchile',
  'CN' => 'Uchina',
  'CO' => 'Ukolombia',
  'CU' => 'Ukuba',
  'CY' => 'Ukuprosi',
  'CZ' => 'Ucheki',
  'DJ' => 'Ujibuti',
  'DK' => 'Udenimaka',
  'DM' => 'Udominika',
  'DZ' => 'Alujeria',
  'EG' => 'Umisiri',
  'ER' => 'Uriterea',
  'ES' => 'Uhispania',
  'ET' => 'Uhabeshi',
  'FI' => 'Ufini',
  'FJ' => 'Ufiji',
  'FR' => 'Ufaransa',
  'GA' => 'Ugaboni',
  'GD' => 'Ugrenada',
  'GE' => 'Ujojia',
  'GF' => 'Ufaransa yo Gwaya',
  'GH' => 'Ugana',
  'GI' => 'Ujibralta',
  'GL' => 'Ugrinlandi',
  'GM' => 'Ugambia',
  'GN' => 'Ugine',
  'GP' => 'Ugwadelupe',
  'GT' => 'Ugwatemala',
  'GU' => 'Ugwam',
  'GW' => 'Uginebisau',
  'GY' => 'Uguyana',
  'HN' => 'Uhondurasi',
  'HR' => 'Ukorasia',
  'HT' => 'Uhaiti',
  'HU' => 'Uhungaria',
  'ID' => 'Undonesia',
  'IE' => 'Uayalandi',
  'IL' => 'Uisraeli',
  'IN' => 'Uhindini',
  'IQ' => 'Wiraki',
  'IT' => 'Italia',
  'JM' => 'Ujamaika',
  'JO' => 'Uyordani',
  'JP' => 'Ujapani',
  'KE' => 'Ukenya',
  'KH' => 'Ukambodia',
  'KM' => 'Ukomoro',
  'KN' => 'Usantakitzi na Nevis',
  'KP' => 'Ukorea Kaskazini',
  'KR' => 'Ukorea Kusini',
  'KZ' => 'Ukazakistani',
  'LB' => 'Ulebanoni',
  'LC' => 'Usantalusia',
  'LI' => 'Ushenteni',
  'LK' => 'Usirilanka',
  'LR' => 'Uliberia',
  'LS' => 'Ulesoto',
  'LT' => 'Utwania',
  'LU' => 'Usembaji',
  'LV' => 'Ulativia',
  'LY' => 'Ulibya',
  'ME' => 'Umantegro',
  'MG' => 'Ubukini',
  'MW' => 'Umalawi',
  'MZ' => 'Umozambiki',
  'NE' => 'Unijeri',
  'NG' => 'Unijeria',
  'NO' => 'Unorwe',
  'OM' => 'Uomani',
  'PA' => 'Upanama',
  'PE' => 'Uperuu',
  'PF' => 'Ufaransa yo Potina',
  'PG' => 'Upapua',
  'PH' => 'Ufilipino',
  'PK' => 'Upakistani',
  'PL' => 'Upolandi',
  'PM' => 'Usantapieri na Mikeloni',
  'PN' => 'Upitkairni',
  'PR' => 'Upwetoriko',
  'PY' => 'Paragwai',
  'QA' => 'Ukatari',
  'RE' => 'Uriyunioni',
  'RO' => 'Uromania',
  'RW' => 'Urwanda',
  'SA' => 'Usaudi',
  'SC' => 'Ushelisheli',
  'SD' => 'Usudani',
  'SE' => 'Uswidi',
  'SG' => 'Usingapoo',
  'SH' => 'Usantahelena',
  'SI' => 'Uslovenia',
  'SK' => 'Uslovakia',
  'SM' => 'Usamarino',
  'SN' => 'Usenegali',
  'SO' => 'Usomalia',
  'SR' => 'Usurinamu',
  'ST' => 'Usao Tome na Principe',
  'SV' => 'Usalavado',
  'SY' => 'Usiria',
  'SZ' => 'Uswazi',
  'TD' => 'Uchadi',
  'TG' => 'Utogo',
  'TH' => 'Utailandi',
  'TJ' => 'Ujikistani',
  'TK' => 'Utokelau',
  'TL' => 'Utimo Mashariki',
  'TM' => 'Uturukimenistani',
  'TN' => 'Utunisia',
  'TO' => 'Utonga',
  'TR' => 'Utuki',
  'TT' => 'Utrinidad na Tobago',
  'TV' => 'Utuvalu',
  'TZ' => 'Utanzania',
  'US' => 'Umarekani',
  'VA' => 'Uvatikani',
  'VC' => 'Usantavisenti na Grenadini',
  'VE' => 'Uvenezuela',
  'VN' => 'Uvietinamu',
  'VU' => 'Uvanuatu',
  'WF' => 'Uwalis na Futuna',
  'WS' => 'Usamoa',
  'YE' => 'Uyemeni',
  'ZA' => 'Afrika du Sulu',
  'ZM' => 'Uzambia',
  'ZW' => 'Uzimbabwe',
);
