<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Formats for dates, hours, etc.
    |--------------------------------------------------------------------------
    |
    | The following language lines are used for date formatting.
    | Be careful to translate it to the right format.
    |
    | We use Carbon to format dates, see http://carbon.nesbot.com/docs/#api-commonformats
    | Format parameters are describe here http://www.php.net/manual/en/function.date.php
    |
    */

    'short_date_year_time' => 'M d, Y H:i',
    'short_date_year' => 'M d, Y',
    'short_date' => 'M d',
    'short_month' => 'M',
    'short_month_year' => 'M Y',
    'short_day' => 'D',
    'full_date_year' => 'F d, Y',
    'full_month' => 'F',
    'full_month_year' => 'F Y',
    'full_hour' => 'h.i A',

    'short_text' => '{text}…',
];
