<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  8862 => 'Taipei',
  8863 => 'Taoyuan/Hsinchu/Yilan/Hualien',
  88637 => 'Miaoli',
  8864001 => 'Taichung/Changhua',
  8864002 => 'Taichung/Changhua',
  8864003 => 'Taichung/Changhua',
  8864004 => 'Taichung/Changhua',
  8864005 => 'Taichung/Changhua',
  8864006 => 'Taichung/Changhua',
  8864007 => 'Taichung/Changhua',
  8864008 => 'Taichung/Changhua',
  8864009 => 'Taichung/Changhua',
  886402 => 'Taichung/Changhua',
  886403 => 'Taichung/Changhua',
  886404 => 'Taichung/Changhua',
  886408 => 'Taichung/Changhua',
  88641 => 'Taichung/Changhua',
  88642 => 'Taichung/Changhua',
  88643 => 'Taichung/Changhua',
  88644 => 'Taichung/Changhua',
  88647 => 'Taichung/Changhua',
  88648 => 'Taichung/Changhua',
  88649 => 'Nantou',
  88652 => 'Chiayi/Yunlin',
  88653 => 'Chiayi/Yunlin',
  88654 => 'Chiayi/Yunlin',
  88655 => 'Chiayi/Yunlin',
  88656 => 'Chiayi/Yunlin',
  88657 => 'Chiayi/Yunlin',
  88658 => 'Chiayi/Yunlin',
  8866 => 'Tainan/Penghu',
  88671 => 'Kaohsiung',
  88672 => 'Kaohsiung',
  88673 => 'Kaohsiung',
  88674 => 'Kaohsiung',
  88675 => 'Kaohsiung',
  88676 => 'Kaohsiung',
  88677 => 'Kaohsiung',
  88678 => 'Kaohsiung',
  88679 => 'Kaohsiung',
  88680 => 'Pingtung',
  886823 => 'Kinmen',
  886824 => 'Kinmen',
  886825 => 'Kinmen',
  886826 => 'Wuqiu',
  886827 => 'Kinmen',
  886828 => 'Kinmen',
  88683 => 'Matsu',
  88684 => 'Pingtung',
  88687 => 'Pingtung',
  88688 => 'Pingtung',
  88689 => 'Taitung',
);
