<?php

namespace OK\Ipstack\Entity\Params;

use OK\Ipstack\Exceptions\InvalidParameterException;

/**
 * @author Oleg Kochetkov <oleg.kochetkov999@yandex.ru>
 */
class IpapiParams extends IpstackParams implements ParameterBagInterface
{
}
