.StripeElement {
  background-color: #ffffff;
  height: 45px;
  width: 100%;
  padding: 13px 12px;
  border-radius: 4px;
  border: 1px solid #999999;
  -webkit-transition: box-shadow 150ms ease;
  transition: box-shadow 150ms ease;
}

.StripeElement--focus {
  box-shadow: 0 1px 3px 0 #d0d0d0;
}

.StripeElement--invalid {
  border-color: #d9534f;
}

.StripeElement--webkit-autofill {
  background-color: #fffacd !important;
}
