<?php
namespace Aws\RoboMaker\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS RoboMaker** service.
 */
class RoboMakerException extends AwsException {}
