<?php
// This file was auto-generated from sdk-root/src/data/route53domains/2014-05-15/paginators-1.json
return [ 'pagination' => [ 'ListDomains' => [ 'input_token' => 'Marker', 'limit_key' => 'MaxItems', 'output_token' => 'NextPageMarker', 'result_key' => 'Domains', ], 'ListOperations' => [ 'input_token' => 'Marker', 'limit_key' => 'MaxItems', 'output_token' => 'NextPageMarker', 'result_key' => 'Operations', ], 'ListPrices' => [ 'input_token' => 'Marker', 'limit_key' => 'MaxItems', 'output_token' => 'NextPageMarker', 'result_key' => 'Prices', ], 'ViewBilling' => [ 'input_token' => 'Marker', 'limit_key' => 'MaxItems', 'output_token' => 'NextPageMarker', 'result_key' => 'BillingRecords', ], ],];
