<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  511 => 'Lima/Callao',
  5141 => 'Amazonas',
  5142 => 'San Martín',
  5143 => 'Ancash',
  5144 => 'La Libertad',
  5151 => 'Puno',
  5152 => 'Tacna',
  5153 => 'Moquegua',
  5154 => 'Arequipa',
  5156 => 'Ica',
  5161 => 'Ucayali',
  5162 => 'Huánuco',
  5163 => 'Pasco',
  5164 => 'Junín',
  5165 => 'Loreto',
  5166 => 'Ayacucho',
  5167 => 'Huancavelica',
  5172 => 'Tumbes',
  5173 => 'Piura',
  5174 => 'Lambayeque',
  5176 => 'Cajamarca',
  5182 => 'Madre de Dios',
  5183 => 'Apurímac',
  5184 => 'Cusco',
);
