<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  34844 => 'Vizcaya',
  34845 => 'Álava',
  34846 => 'Vizcaya',
  34848 => 'Navarra',
  34850 => 'Álmería',
  34854 => 'Sevilla',
  34857 => 'Córdoba',
  34871 => 'Baleares',
  34872 => 'Gerona',
  34873 => 'Lérida',
  34888 => 'Orense',
  34944 => 'Vizcaya',
  34945 => 'Álava',
  34946 => 'Vizcaya',
  34948 => 'Navarra',
  34954 => 'Sevilla',
  34955 => 'Sevilla',
  34957 => 'Córdoba',
  34971 => 'Baleares',
  34972 => 'Gerona',
  349730 => 'Lérida',
  349731 => 'Lérida',
  349732 => 'Lérida',
  349733 => 'Lérida',
  349734 => 'Lérida',
  349735 => 'Lérida',
  349736 => 'Lérida',
  349737 => 'Lérida',
  349738 => 'Lérida',
  3497391 => 'Lérida',
  3497392 => 'Lérida',
  3497393 => 'Lérida',
  3497394 => 'Lérida',
  3497395 => 'Lérida',
  3497396 => 'Lérida',
  3497397 => 'Lérida',
  3497398 => 'Lérida',
  3497399 => 'Lérida',
  34981 => 'A Coruña',
  34988 => 'Orense',
);
