<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    //index
    'people_not_found' => 'Contact not found',
    'people_list_number_kids' => ':count child|:count children',
    'people_list_last_updated' => 'آخر استشارة:',
    'people_list_number_reminders' => ':count reminder|:count reminders',
    'people_list_blank_title' => 'ليس لديك أي شخص في الحساب الخاص بك بعد',
    'people_list_blank_cta' => 'أضف شخص',
    'people_list_sort' => 'ترتيب',
    'people_list_stats' => ':count contact|:count contacts',
    'people_list_firstnameAZ' => 'فرز حسب الاسم الأول A → Z',
    'people_list_firstnameZA' => 'فرز حسب الاسم الأول Z → A',
    'people_list_lastnameAZ' => 'فرز حسب الاسم الأخير A → Z',
    'people_list_lastnameZA' => 'فرز حسب اسم العائلة Z → A',
    'people_list_lastactivitydateNewtoOld' => 'Sort by last activity date, newest to oldest',
    'people_list_lastactivitydateOldtoNew' => 'Sort by last activity date, oldest to newest',
    'people_list_filter_tag' => 'عرض كل جهات الاتصال ذات الوسم',
    'people_list_clear_filter' => 'مسح التصفية',
    'people_list_contacts_per_tags' => ':count contact|:count contacts',
    'people_list_show_dead' => 'Show deceased people (:count)',
    'people_list_hide_dead' => 'Hide deceased people (:count)',
    'people_search' => 'Search your contacts…',
    'people_search_no_results' => 'No results found',
    'people_search_next' => 'Next',
    'people_search_prev' => 'Previous',
    'people_search_rows_per_page' => 'Rows per page',
    'people_search_of' => 'of',
    'people_search_page' => 'Page',
    'people_search_all' => 'All',
    'people_add_new' => 'Add new person',
    'people_list_account_usage' => 'استخدام حسابك: :current/:limit جهة اتصال',
    'people_list_account_upgrade_title' => 'قم بترقية حسابك لتفعيل كامل إمكانياته.',
    'people_list_account_upgrade_cta' => 'قم بالترقية الان',
    'people_list_untagged' => 'عرض جهات الاتصال الغير موسومة',
    'people_list_filter_untag' => 'عرض كل جهات الاتصال الغير موسومة',
    'archived_contact_readonly' => 'Archived contact can’t be edited, please unarchive it first.',

    // people add
    'people_add_title' => 'إضافة شخص جديد',
    'people_add_missing' => 'No person found – add a new one now',
    'people_add_firstname' => 'الاسم الأول',
    'people_add_middlename' => 'Middle name (optional)',
    'people_add_lastname' => 'Last name (optional)',
    'people_add_email' => 'Email (optional)',
    'people_add_nickname' => 'Nickname (optional)',
    'people_add_cta' => 'إضافة',
    'people_save_and_add_another_cta' => 'تقديم وأضف شخص آخر',
    'people_add_success' => ':name تم إضافته بنجاح',
    'people_add_gender' => 'الجنس',
    'people_delete_success' => 'تم حذف جهة الاتصال',
    'people_delete_message' => 'Delete contact',
    'people_delete_confirmation' => 'Are you sure you want to delete :name’s contact? Deletion is immediate and permanent.',
    'people_add_birthday_reminder' => 'تمنى :name عيد ميلاد سعيد',
    'people_add_birthday_reminder_deceased' => 'On this date, :name would have celebrated their birthday',
    'people_add_import' => 'هل تريد <a href=":url">استيراد جهات الاتصال الخاصة بك</a>؟',
    'people_edit_email_error' => 'يوجد جهة اتصال في حسابك بنفس عنوان البريد الالكتروني. الرجاء اختيار عنوان آخر.',
    'people_export' => 'تصدير ك vCard',
    'people_add_reminder_for_birthday' => 'Create an annual birthday reminder',

    // show
    'section_contact_information' => 'معلومات جهة الاتصال',
    'section_personal_activities' => 'الأنشطة',
    'section_personal_reminders' => 'رسائل تذكير',
    'section_personal_tasks' => 'المهام',
    'section_personal_gifts' => 'الهدايا',
    'section_personal_notes' => 'الملاحظات',

    // archived contacts
    'list_link_to_active_contacts' => 'You are viewing archived contacts. See the <a href=":url">list of active contacts</a> instead.',
    'list_link_to_archived_contacts' => 'List of archived contacts',

    // Header
    'me' => 'This is you',
    'edit_contact_information' => 'تعديل معلومات الإتصال',
    'contact_archive' => 'Archive contact',
    'contact_unarchive' => 'Unarchive contact',
    'contact_archive_help' => 'Archived contacts are not be shown on the contact list, but still appear in search results.',
    'call_button' => 'تسجيل مكالمة',
    'set_favorite' => 'جهات الاتصال المفضلة يتم وضعها في قمة قائمة جهات الاتصال',

    // Stay in touch
    'stay_in_touch' => 'ابقى على اتصال',
    'stay_in_touch_frequency' => 'ابقى على اتصال يوميا|ابقى على اتصال كل {count} يومًا',
    'stay_in_touch_next_date' => 'Next due: {date}',
    'stay_in_touch_invalid' => 'يجب أن يكون التواتر عدد أكبر من 0.',
    'stay_in_touch_premium' => 'تحتاج إلى ترقية الحساب الخاص بك لاستخدام هذه الميزة',
    'stay_in_touch_modal_title' => 'ابقى على اتصال',
    'stay_in_touch_modal_desc' => 'يمكن أن نذكرك عن طريق البريد الإلكتروني للبقاء على اتصال مع {firstname} على فترات منتظمة.',
    'stay_in_touch_modal_label' => 'Send me an email every… {count} day|Send me an email every… {count} days',

    // Calls
    'modal_call_title' => 'تسجيل مكالمة',
    'modal_call_comment' => 'ماذا تحدثتم عنه؟ (اختياري)',
    'modal_call_exact_date' => 'تمت المكالمة الهاتفية في',
    'modal_call_who_called' => 'Who called?',
    'modal_call_emotion' => 'Do you want to log how you felt during this call? (optional)',
    'calls_add_success' => 'تم حفظ المكالمة الهاتفية.',
    'call_delete_confirmation' => 'هل أنت متأكد من حذف هذه المكالمة؟',
    'call_delete_success' => 'تم حذف المكالمة بنجاح',
    'call_title' => 'المكالمات الهاتفية',
    'call_empty_comment' => 'لا تفاصيل',
    'call_blank_title' => 'Keep track of the phone calls you’ve done with {name}',
    'call_blank_desc' => 'You called {name}',
    'call_you_called' => 'You called',
    'call_he_called' => '{name} called',
    'call_emotions' => 'Emotions:',

    // Conversation
    'conversation_blank' => 'Record conversations you have with :name on social media, SMS…',
    'conversation_delete_link' => 'حذف المحادثة',
    'conversation_edit_title' => 'تحرير المحادثة',
    'conversation_edit_delete' => 'هل أنت متأكد من حذف هذه المحادثة؟ الحذف دائم.',
    'conversation_add_success' => 'The conversation has been successfully added.',
    'conversation_edit_success' => 'The conversation has been successfully updated.',
    'conversation_delete_success' => 'لقد تم حذف المحادثة بنجاح.',
    'conversation_add_title' => 'سَجل محادثة جديدة',
    'conversation_add_when' => 'متى تمت هذه المحادثة؟',
    'conversation_add_who_wrote' => 'Who sent this message?',
    'conversation_add_how' => 'كيف تواصلتما؟',
    'conversation_add_you' => 'أنت',
    'conversation_add_content' => 'قم بتدوين ما قيل',
    'conversation_add_what_was_said' => 'ماذا قلت؟',
    'conversation_add_another' => 'إضافة رسالة أخرى',
    'conversation_add_error' => 'You must add at least one message.',
    'conversation_list_table_messages' => 'الرسائل',
    'conversation_list_table_content' => 'محتوى جزئي (آخر رسالة)',
    'conversation_list_title' => 'المحادثات',
    'conversation_list_cta' => 'سجل المحادثة',

    // age - birthday
    'birthdate_not_set' => 'Birthday is not set',
    'age_approximate_in_years' => ':age سنوات تقريبًا',
    'age_exact_in_years' => ':age سنوات',
    'age_exact_birthdate' => 'ولد في :date',

    // Last called
    'last_called' => 'Last called: :date',
    'last_talked_to' => 'Last called: {date}',
    'last_called_empty' => 'Last called: unknown',
    'last_activity_date' => 'Last activity together: :date',
    'last_activity_date_empty' => 'Last activity together: unknown',

    // additional information
    'information_edit_success' => 'تم تحديث الملف الشخصي بنجاح',
    'information_edit_title' => 'تعديل معلومات :name الشخصية',
    'information_edit_max_size' => 'الحد الأقصى :size كيلوبايت.',
    'information_edit_max_size2' => 'Max {size} Kb.',
    'information_edit_firstname' => 'الاسم الأول',
    'information_edit_lastname' => 'Last name (optional)',
    'information_edit_description' => 'Description (optional)',
    'information_edit_description_help' => 'تستخدم في قائمة جهات الاتصال لإضافة بعض المعلومات، إذا لزم الأمر.',
    'information_edit_unknown' => 'أنا لا أعرف عمر هذا الشخص',
    'information_edit_probably' => 'This person is probably…',
    'information_edit_not_year' => 'I know the day and month of this person’s birthday, but not the year…',
    'information_edit_exact' => 'I know this person’s exact birthday…',
    'information_edit_birthdate_label' => 'Birthday',
    'information_no_work_defined' => 'لا توجد معلومات العمل',
    'information_work_at' => 'لدى :company',
    'work_add_cta' => 'تحديث معلومات العمل',
    'work_edit_success' => 'Work information updated',
    'work_edit_title' => 'تحيث معلومات العمل الخاصة بـ :name',
    'work_edit_job' => 'المسمى الوظيفي (اختياري)',
    'work_edit_company' => 'الشركة (اختياري)',
    'work_information' => 'معلومات العمل',

    // food preferences
    'food_preferences_add_success' => 'تم حفظ التفضيلات الغذائية',
    'food_preferences_edit_description' => 'قد يكون :firstname أو شخص في عائلة :family مصاب بالحساسية، أو لا يريد نوع معين من النبيذ. حدد ذلك هنا لكي تتذكر ذلك في المرة القادمة عندما تدعوهم للعشاء',
    'food_preferences_edit_description_no_last_name' => 'قد يكون :firstname مصاب بالحساسية، أو لا يريد نوع معين من النبيذ. حدد ذلك هنا لكي تتذكر ذلك في المرة القادمة عندما تدعوهم للعشاء',
    'food_preferences_edit_title' => 'حدد التفضيلات الغذائية',
    'food_preferences_edit_cta' => 'حفظ التفضيلات الغذائية',
    'food_preferences_title' => 'التفضيلات الغذائية',
    'food_preferences_cta' => 'أضف تفضيلات غذائية',

    // reminders
    'reminders_blank_title' => 'هل هناك شيء ما كنت ترغب أن يتم تذكيرك به بخصوص :name؟',
    'reminders_blank_add_activity' => 'إضافة تذكير',
    'reminders_add_title' => 'ما الذي ترغب بتذكره عن :name؟',
    'reminders_add_description' => 'Please remind me to…',
    'reminders_add_next_time' => 'متى تود أن تكون المرة القادمة التي يتم فيها تذكيرك بهذا؟',
    'reminders_add_once' => 'ذكرني بهذا مرة واحدة فقط',
    'reminders_add_recurrent' => 'ذكرني بهذا كل',
    'reminders_add_starting_from' => 'ابتداءً من التاريخ الموضح أعلاه',
    'reminders_add_cta' => 'إضافة تذكير',
    'reminders_edit_update_cta' => 'تحديث التذكير',
    'reminders_add_error_custom_text' => 'يجب إضافة نص لهذا التذكير',
    'reminders_create_success' => 'تم بنجاح إضافة تذكير',
    'reminders_delete_success' => 'تم حذف التذكير بنجاح',
    'reminders_update_success' => 'تم تحديث التذكير بنجاح',
    'reminders_add_optional_comment' => 'Optional comment',

    'reminder_frequency_day' => 'يوميا|كل :number أيام',
    'reminder_frequency_week' => 'أسبوعيا|كل :number أسابيع',
    'reminder_frequency_month' => 'شهريا|كل :number أشهر',
    'reminder_frequency_year' => 'سنويا|كل :number سنوات',
    'reminder_frequency_one_time' => 'في :date',
    'reminders_delete_confirmation' => 'هل تريد فعلا حذف هذا التذكير؟',
    'reminders_delete_cta' => 'حذف',
    'reminders_next_expected_date' => 'على',
    'reminders_cta' => 'إضافة تذكير',
    'reminders_description' => 'We will send an email for each one of the reminders below. Reminders are sent every morning the day events will happen. Reminders automatically added for birthdays can not be deleted. If you want to change those dates, edit the birthday of the contacts.',
    'reminders_one_time' => 'مرة واحدة',
    'reminders_type_week' => 'أسبوع',
    'reminders_type_month' => 'شهر',
    'reminders_type_year' => 'سنة',
    'reminders_birthday' => 'عيد ميلاد :name',
    'reminders_free_plan_warning' => 'أنت على الخطة المجانية. لا يتم إرسال رسائل الكترونية في هذه الخطة. قم بترقية حسابك لاستلام رسائل الكترونية.',

    // relationships
    'relationship_form_add' => 'إضافة علاقة جديدة',
    'relationship_form_edit' => 'تعديل علاقة حالية',
    'relationship_form_is_with' => 'This person is…',
    'relationship_form_is_with_name' => ':name is…',
    'relationship_form_add_choice' => 'مع من هذه العلاقة؟',
    'relationship_form_create_contact' => 'إضافة شخص جديد',
    'relationship_form_associate_contact' => 'جهة اتصال موجودة',
    'relationship_form_associate_dropdown' => 'بحث واختيار جهة اتصال موجودة من القائمة المنسدلة أدناه',
    'relationship_form_associate_dropdown_placeholder' => 'بحث واختيار جهة اتصال موجودة',
    'relationship_form_also_create_contact' => 'إنشاء جهة اتصال لهذا الشخص.',
    'relationship_form_add_description' => 'This will let you treat this person like any other contact.',
    'relationship_form_add_no_existing_contact' => 'ليس لديك أي جهة اتصال قد تكون على قرابة بـ:name حاليا.',
    'relationship_delete_confirmation' => 'هل أنت متأكد من أنك تريد حذف هذه العلاقة؟ الحذف دائم.',
    'relationship_unlink_confirmation' => 'هل أنت متأكد من أنك تريد حذف هذه العلاقة؟ لن يتم حذف هذا الشخص – فقط العلاقة بين الشخصين.',
    'relationship_form_add_success' => 'تم تعيين العلاقة بنجاح.',
    'relationship_form_deletion_success' => 'تم حذف العلاقة.',

    // tasks
    'tasks_title' => 'Tasks',
    'tasks_blank_title' => 'ليس لديك مهام حتى الآن.',
    'tasks_form_title' => 'العنوان',
    'tasks_form_description' => 'الوصف (اختياري)',
    'tasks_add_task' => 'إضافة مهمة',
    'tasks_delete_success' => 'تم حذف المهمة بنجاح',
    'tasks_complete_success' => 'تم تغيير حالة المهمة بنجاح',

    // activities
    'activity_title' => 'الأنشطة',
    'activity_type_category_simple_activities' => 'أنشطة بسيطة',
    'activity_type_category_sport' => 'رياضة',
    'activity_type_category_food' => 'طعام',
    'activity_type_category_cultural_activities' => 'أنشطة ثقافية',
    'activity_type_just_hung_out' => 'قضينا الوقت معا',
    'activity_type_watched_movie_at_home' => 'شاهدنا فيلم في المنزل',
    'activity_type_talked_at_home' => 'تحدثنا في المنزل',
    'activity_type_did_sport_activities_together' => 'played a sport together',
    'activity_type_ate_at_his_place' => 'تناولنا الطعام بمنزلهم',
    'activity_type_went_bar' => 'ذهبنا إلى حانة',
    'activity_type_ate_at_home' => 'تناولنا الطعام في المنزل',
    'activity_type_picnicked' => 'picnicked',
    'activity_type_ate_restaurant' => 'تناولنا الطعام في المطعم',
    'activity_type_went_theater' => 'ذهبنا إلى دار العرض',
    'activity_type_went_concert' => 'ذهبنا إلى حفلة موسيقية',
    'activity_type_went_play' => 'ذهبنا إلى مسرحية',
    'activity_type_went_museum' => 'ذهبنا إلى المتحف',
    'activities_add_activity' => 'إضافة نشاط',
    'activities_add_more_details' => 'Add more details',
    'activities_add_emotions' => 'Add emotions',
    'activities_add_category' => 'Indicate a category',
    'activities_add_participants_cta' => 'Add participants',
    'activities_item_information' => ':Activity حدث في :date',
    'activities_add_title' => 'What did you do with {name}?',
    'activities_summary' => 'صف ما فعلته',
    'activities_add_pick_activity' => 'Would you like to categorize this activity? You don’t have to, but it will give you statistics later on (optional)',
    'activities_add_date_occured' => 'The activity happened on…',
    'activities_add_participants' => 'Who, apart from {name}, participated in this activity? (optional)',
    'activities_add_emotions_title' => 'Do you want to log how you felt during this activity? (optional)',
    'activities_blank_title' => 'Keep track of what you’ve done with {name} in the past, and what you’ve talked about',
    'activities_blank_add_activity' => 'إضافة نشاط',
    'activities_add_success' => 'تم إضافة النشاط بنجاح',
    'activities_add_error' => 'خطأ عند إضافة نشاط',
    'activities_update_success' => 'تم تحديث النشاط بنجاح',
    'activities_delete_success' => 'تم حذف النشاط بنجاح',
    'activities_who_was_involved' => 'من شارك؟',
    'activities_activity' => 'تصنيف النشاط',
    'activities_view_activities_report' => 'عرض تقرير الأنشطة',
    'activities_profile_title' => 'تقرير عن الأنشطة بينك وبين :name',
    'activities_profile_subtitle' => 'لقد سجلت :total_activities نشاطا مع :name إجمالا، و:activities_last_twelve_months خلال الاثناعشر شهرا الماضية حتى الآن.|لقد سجلت :total_activities نشاطا مع :name إجمالا، و:activities_last_twelve_months خلال الاثناعشر شهرا الماضية حتى الآن.',
    'activities_profile_year_summary_activity_types' => 'هنا تفاصيل هذا النوع من الأنشطة التي قضيتماها معا في عام :year',
    'activities_profile_year_summary' => 'هذا ما فعلتموه معا في عام :year',
    'activities_profile_number_occurences' => ':value نشاط|:value أنشطة',
    'activities_list_participants' => 'Participants ({total}):',
    'activities_list_emotions' => 'Emotions felt:',
    'activities_list_date' => 'Happened on',
    'activities_list_category' => 'Category:',

    // notes
    'notes_create_success' => 'تم إنشاء المذكرة بنجاح',
    'notes_update_success' => 'تم حفظ المذكرة بنجاح',
    'notes_delete_success' => 'تم حذف المذكرة بنجاح',
    'notes_add_cta' => 'إضافة ملاحظة',
    'notes_favorite' => 'إضافة/إزالة من المفضلة',
    'notes_delete_title' => 'حذف ملاحظة',
    'notes_delete_confirmation' => 'هل أنت متأكذ من أنك تريد حذف هذه المذكرة؟ الحذف دائم',

    // gifts
    'gifts_title' => 'الهدايا',
    'gifts_add_success' => 'تم بنجاح إضافة هدية',
    'gifts_delete_success' => 'تم بنجاح حذف هدية',
    'gifts_delete_confirmation' => 'هل أنت متأكد من أنك تريد حذف هذه الهدية؟',
    'gifts_add_gift' => 'إضافة هدية',
    'gifts_link' => 'الرابط',
    'gifts_for' => 'For: {name}',
    'gifts_delete_cta' => 'حذف',
    'gifts_add_title' => 'إدارة الهدايا لـ :name',
    'gifts_add_gift_idea' => 'فكرة هدية',
    'gifts_add_gift_already_offered' => 'هدية تم تقديمها',
    'gifts_add_gift_received' => 'هدية تم استلامها',
    'gifts_add_gift_title' => 'ما هذه الهدية؟',
    'gifts_add_gift_name' => 'Gift name',
    'gifts_add_link' => 'الرابط لصفحة الويب (اختياري)',
    'gifts_add_value' => 'القيمة (اختياري)',
    'gifts_add_comment' => 'تعليق (اختياري)',
    'gifts_add_recipient' => 'Recipient (optional)',
    'gifts_add_recipient_field' => 'Recipient',
    'gifts_add_photo' => 'Photo (optional)',
    'gifts_add_photo_title' => 'Add a photo for this gift',
    'gifts_add_someone' => 'This gift is for someone in {name}’s family in particular',
    'gifts_delete_title' => 'Delete a gift',
    'gifts_ideas' => 'أفكار للهدايا',
    'gifts_offered' => 'هدية تم تقديمها',
    'gifts_offered_as_an_idea' => 'وضع علامة كفكرة',
    'gifts_received' => 'استلام هدية',
    'gifts_view_comment' => 'عرض التعليق',
    'gifts_mark_offered' => 'ضع علامة بأنه تم عرضها',
    'gifts_update_success' => 'تم بنجاح تحديث هدية',
    'gifts_add_date' => 'Date (optional)',

    // debts
    'debt_delete_confirmation' => 'هل أنت متأكد من أنك تريد حذف هذا الدين؟',
    'debt_delete_success' => 'تم بنجاح حذف الدين',
    'debt_add_success' => 'تم بنجاح إضافة الدين',
    'debt_title' => 'الديون',
    'debt_add_cta' => 'إضافة دين',
    'debt_you_owe' => 'أنت مدين بـ :amount',
    'debt_they_owe' => ':name مدين لك بـ :amount',
    'debt_add_title' => 'إدارة الديون',
    'debt_add_you_owe' => 'أنت مدين لـ :name',
    'debt_add_they_owe' => ':name مدين لك',
    'debt_add_amount' => 'مجموع',
    'debt_add_reason' => 'للسبب التالي (اختياري)',
    'debt_add_add_cta' => 'إضافة دين',
    'debt_edit_update_cta' => 'تحديث الدين',
    'debt_edit_success' => 'تم بنجاح تحديث الدين',
    'debts_blank_title' => 'إدارة الديون التي تدين بها لـ:name أو يدين بها :name لك',

    // tags
    'tag_edit' => 'تعديل وسم',
    'tag_add' => 'Add tags',
    'tag_add_search' => 'Add or search tags',
    'tag_no_tags' => 'No tags yet',

    // Introductions
    'introductions_sidebar_title' => 'كيف إلتقيتم',
    'introductions_blank_cta' => 'حدد كيف قابلت :name',
    'introductions_title_edit' => 'كيف التقيت بـ :name؟',
    'introductions_additional_info' => 'اشرح كيف وأين إلتقيتم',
    'introductions_edit_met_through' => 'هل عرّفك أحد بهذا الشخص؟',
    'introductions_no_met_through' => 'لا أحد',
    'introductions_first_met_date' => 'تاريخ اللقاء',
    'introductions_no_first_met_date' => 'لا أعرف تاريخ اللقاء الأول',
    'introductions_first_met_date_known' => 'هذا هو تاريخ اللقاء الأول',
    'introductions_add_reminder' => 'أضف تذكير للاحتفال بذكرى هذه المناسبة',
    'introductions_update_success' => 'لقد حدثت معلومات كيفية لقائك هذا الشخص بنجاح',
    'introductions_met_through' => 'التقينا بواسطة <a href=":url">:name</a>',
    'introductions_met_date' => 'التقينا في :date',
    'introductions_reminder_title' => 'الذكرى السنوية لليوم الذي التقيتم فيه للمرة الأولى',

    // Deceased
    'deceased_reminder_title' => 'الذكرى السنوية لوفاة :name',
    'deceased_mark_person_deceased' => 'Mark this as deceased',
    'deceased_know_date' => 'I know the date that this person died',
    'deceased_add_reminder' => 'إضافة تذكير لهذا التاريخ',
    'deceased_label' => 'متوفى',
    'deceased_date_label' => 'Deceased date',
    'deceased_label_with_date' => 'توفي بتاريخ :date',
    'deceased_age' => 'العمر عند الوفاة',

    // Contact information
    'contact_info_title' => 'معلومات جهة الاتصال',
    'contact_info_form_content' => 'المحتوى',
    'contact_info_form_contact_type' => 'نوع الاتصال',
    'contact_info_form_personalize' => 'إضفاء طابع شخصي',
    'contact_info_address' => 'يعيش في',

    // Addresses
    'contact_address_title' => 'عناوين',
    'contact_address_form_name' => 'تسمية (اختياري)',
    'contact_address_form_street' => 'الشارع (اختياري)',
    'contact_address_form_city' => 'المدينة (اختياري)',
    'contact_address_form_province' => 'المنطقة (اختياري)',
    'contact_address_form_postal_code' => 'الرمز البريدي (اختياري)',
    'contact_address_form_country' => 'البلد (اختياري)',
    'contact_address_form_latitude' => 'Latitude (numbers only) (optional)',
    'contact_address_form_longitude' => 'Longitude (numbers only) (optional)',

    // Pets
    'pets_kind' => 'نوع الحيوان الأليف',
    'pets_name' => 'الاسم (اختيارى)',
    'pets_create_success' => 'The pet has been successfully added',
    'pets_update_success' => 'تم تحديث الحيوان الأليف',
    'pets_delete_success' => 'تم حذف الحيوان الأليف',
    'pets_title' => 'الحيوانات الأليفة',
    'pets_reptile' => 'زواحف',
    'pets_bird' => 'طيور',
    'pets_cat' => 'قطط',
    'pets_dog' => 'كلاب',
    'pets_fish' => 'أسماك',
    'pets_hamster' => 'هامستر',
    'pets_horse' => 'حصان',
    'pets_rabbit' => 'أرنب',
    'pets_rat' => 'جرذ',
    'pets_small_animal' => 'حيوانات صغيرة',
    'pets_other' => 'غير ذلك',

    // life events
    'life_event_list_tab_life_events' => 'أحداث الحياة',
    'life_event_list_tab_other' => 'Notes, reminders, …',
    'life_event_list_title' => 'أحداث الحياة',
    'life_event_blank' => 'قم بتسجيل ما يحدث في حياة {name} كمرجع لك في المستقبل.',
    'life_event_list_cta' => 'إضافة حدث الحياة',
    'life_event_create_category' => 'كل الفئات',
    'life_event_create_life_event' => 'إضافة حدث الحياة',
    'life_event_create_default_title' => 'العنوان (اختياري)',
    'life_event_create_default_story' => 'القصة (اختياري)',
    'life_event_create_date' => 'You do not need to indicate a month or a day – only the year is mandatory.',
    'life_event_create_default_description' => 'أضف معلومات حول ما تعرفه',
    'life_event_create_add_yearly_reminder' => 'أضف تذكيراً سنوياً لهذا الحدث',
    'life_event_create_success' => 'تمت إضافة الحدث',
    'life_event_delete_title' => 'حذف حدث الحياة',
    'life_event_delete_description' => 'هل أنت متأكد من أنك تريد حذف هذا الحدث؟ الحذف دائم.',
    'life_event_delete_success' => 'تمت حذف هذا الحدث',
    'life_event_date_it_happened' => 'التاريخ الذي حدث فيه',
    'life_event_category_work_education' => 'Work & education',
    'life_event_category_family_relationships' => 'Family & relationships',
    'life_event_category_home_living' => 'Home & living',
    'life_event_category_health_wellness' => 'Health & wellness',
    'life_event_category_travel_experiences' => 'Travel & experiences',
    'life_event_sentence_new_job' => 'بدأ في عمل جديد',
    'life_event_sentence_retirement' => 'تقاعد',
    'life_event_sentence_new_school' => 'بدأت المدرسة',
    'life_event_sentence_study_abroad' => 'درست خارجاً',
    'life_event_sentence_volunteer_work' => 'بدأت في التطوع',
    'life_event_sentence_published_book_or_paper' => 'نشرت مقال',
    'life_event_sentence_military_service' => 'بدأت الخدمة العسكرية',
    'life_event_sentence_new_relationship' => 'بدأت في علاقة',
    'life_event_sentence_engagement' => 'خطبت',
    'life_event_sentence_marriage' => 'تزوجت',
    'life_event_sentence_anniversary' => 'ذكرى',
    'life_event_sentence_expecting_a_baby' => 'انتظار مولود',
    'life_event_sentence_new_child' => 'رزق بمولود',
    'life_event_sentence_new_family_member' => 'إضافة فرد جديد في العائلة',
    'life_event_sentence_new_pet' => 'Got a pet',
    'life_event_sentence_end_of_relationship' => 'أنهيت علاقة',
    'life_event_sentence_loss_of_a_loved_one' => 'Lost a loved one',
    'life_event_sentence_moved' => 'إنتقل',
    'life_event_sentence_bought_a_home' => 'اشتريت منزل',
    'life_event_sentence_home_improvement' => 'Made a home improvement',
    'life_event_sentence_holidays' => 'ذهبت في عطلة',
    'life_event_sentence_new_vehicle' => 'Got a new vehicle',
    'life_event_sentence_new_roommate' => 'Got a roommate',
    'life_event_sentence_overcame_an_illness' => 'Overcame an illness',
    'life_event_sentence_quit_a_habit' => 'أقلعت عن عادة',
    'life_event_sentence_new_eating_habits' => 'Started new eating habits',
    'life_event_sentence_weight_loss' => 'فقدت الوزن',
    'life_event_sentence_wear_glass_or_contact' => 'بدأت في ارتداء النظارات أو العدسات',
    'life_event_sentence_broken_bone' => 'كسرت عظماً',
    'life_event_sentence_removed_braces' => 'أزلت تقويم الأسنان',
    'life_event_sentence_surgery' => 'Had surgery',
    'life_event_sentence_dentist' => 'ذهبت لطبيب الأسنان',
    'life_event_sentence_new_sport' => 'بدأت في رياضة',
    'life_event_sentence_new_hobby' => 'بدأت هواية',
    'life_event_sentence_new_instrument' => 'تعلم آلة جديدة',
    'life_event_sentence_new_language' => 'تعلمت لغة جديدة',
    'life_event_sentence_tattoo_or_piercing' => 'تلقى وشماً أو ثقب',
    'life_event_sentence_new_license' => 'حصلتُ على رخصة',
    'life_event_sentence_travel' => 'سافرت',
    'life_event_sentence_achievement_or_award' => 'تلقى إنجازاً أو جائزة',
    'life_event_sentence_changed_beliefs' => 'غيرت معتقداتي',
    'life_event_sentence_first_word' => 'تحدث للمرة الأولى',
    'life_event_sentence_first_kiss' => 'Kissed for the first time',

    // documents
    'document_list_title' => 'Documents',
    'document_list_cta' => 'Upload document',
    'document_list_blank_desc' => 'Here you can store documents related to this person.',
    'document_upload_zone_cta' => 'Upload a file',
    'document_upload_zone_progress' => 'Uploading the document…',
    'document_upload_zone_error' => 'There was an error uploading the document. Please try again below.',

    // Photos
    'photo_title' => 'Photos',
    'photo_list_title' => 'Related photos',
    'photo_list_cta' => 'Upload photo',
    'photo_list_blank_desc' => 'You can store images about this contact. Upload one now!',
    'photo_upload_zone_cta' => 'Upload a photo',
    'photo_current_profile_pic' => 'Current profile picture',
    'photo_make_profile_pic' => 'Make profile picture',
    'photo_delete' => 'Delete photo',
    'photo_next' => 'Next photo ❯',
    'photo_previous' => '❮ Previous photo',

    // Avatars
    'avatar_change_title' => 'Change your avatar',
    'avatar_question' => 'Which avatar would you like to use?',
    'avatar_default_avatar' => 'The default avatar',
    'avatar_adorable_avatar' => 'The Adorable avatar',
    'avatar_gravatar' => 'The Gravatar associated with the email address of this person. <a href="https://gravatar.com/">Gravatar</a> is a global system that lets users associate email addresses with photos.',
    'avatar_current' => 'Keep the current avatar',
    'avatar_photo' => 'From a photo that you upload',
    'avatar_crop_new_avatar_photo' => 'Crop new avatar photo',

    // emotions
    'emotion_this_made_me_feel' => 'This made you feel…',

    // logs
    'auditlogs_link' => 'History',
    'auditlogs_title' => 'Everything that happened to :name',
    'auditlogs_breadcrumb' => 'History',
    'auditlogs_author' => 'By :name on :date',

    // contact field label
    'contact_field_label_home' => 'Home',
    'contact_field_label_work' => 'Work',
    'contact_field_label_cell' => 'Mobile',
    'contact_field_label_fax' => 'Fax',
    'contact_field_label_pager' => 'Pager',
    'contact_field_label_main' => 'Main',
    'contact_field_label_other' => 'Other',
    'contact_field_label_personal' => 'Personal',
];
