<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  96311 => 'Damascus and rural areas',
  96312 => 'Al-Nebek',
  96313 => 'Al-Zabadani',
  96314 => 'Al-Quneitra',
  96315 => 'Dara',
  96316 => 'Al-Swedaa',
  96321 => 'Aleppo',
  96322 => 'Al-Rakkah',
  96323 => 'Edleb',
  96325 => 'Menbej',
  96331 => 'Homs',
  96333 => 'Hamah',
  96334 => 'Palmyra',
  96341 => 'Lattakia',
  96343 => 'Tartous',
  96344 => 'Hamah',
  96351 => 'Deir Ezzour',
  96352 => 'Alhasakah',
  96353 => 'Al-Kameshli',
);
