<?php
namespace Aws\LexModelBuildingService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Lex Model Building Service** service.
 */
class LexModelBuildingServiceException extends AwsException {}
