<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => '¿Cómo fue tu día? Puedes valorarlo una vez al día.',
    'journal_come_back' => 'Gracias. Vuelve mañana para puntuar tu día de nuevo.',
    'journal_description' => 'Nota: el diario lista las entradas del diario y las automáticas como Actividades con tus contactos. Aunque puedes borrar las entradas del diario manualmente, la actividad tendrás que borrarla directamente en la página del contacto.',
    'journal_add' => 'Agregar una entrada de diario',
    'journal_edit' => 'Editar página de diario',
    'journal_empty' => 'Borrar diario',
    'journal_created_at' => 'Creada: {date}',
    'journal_created_automatically' => 'Creada autmáticamente',
    'journal_entry_type_journal' => 'Entrada de diario',
    'journal_entry_type_activity' => 'Actividad',
    'journal_entry_rate' => 'Valoraste tú día.',
    'journal_add_comment' => '¿Quieres añadir un comentario (opcional)?',
    'journal_show_comment' => 'Mostrar comentario',
    'entry_delete_success' => 'La entrada de diario ha sido eliminada correctamente.',
    'journal_add_title' => 'Título (opcional)',
    'journal_add_date' => 'Fecha',
    'journal_add_post' => 'Entrada',
    'journal_add_cta' => 'Guardar',
    'journal_blank_cta' => 'Añade tu primera entrada de diario',
    'journal_blank_description' => 'El diario te permite escribir eventos que te han pasado y recordarlos.',
    'delete_confirmation' => '¿Seguro que deseas eliminar esta entrada de tu diario?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
