<?php
namespace Aws\CloudWatchRUM\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **CloudWatch RUM** service.
 */
class CloudWatchRUMException extends AwsException {}
