<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => '¡Bienvenido/a a tu cuenta!',
    'dashboard_blank_description' => 'Monica es el lugar donde organizar todas las interacciones con los que te importan.',
    'dashboard_blank_cta' => 'Añade tu primer contacto',
    'dashboard_blank_illustration' => 'Ilustración por <a href=":url">Freepik</a>',

    'notes_title' => 'Todavía no tienes notas destacadas.',

    'tab_recent_calls' => 'Llamadas recientes',
    'tab_favorite_notes' => 'Notas favoritas',
    'tab_calls_blank' => 'Todavía no has registrado una llamada.',
    'tab_debts' => 'Deudas',
    'tab_debts_blank' => 'Todavía no has registrado una deuda.',
    'tab_tasks' => 'Tareas',
    'tab_tasks_blank' => 'Todavía no tienes ninguna tarea.',

    'tasks_add_task_placeholder' => '¿En qué consiste esta tarea?',
    'tasks_tab_your_contacts' => 'Tareas relacionadas con tus contactos',
    'tasks_tab_your_tasks' => 'Tus tareas',
    'tasks_add_note' => 'Presiona <kbd>Enter</kbd> para añadir la tarea.',
    'task_add_cta' => 'Añadir una tarea',

    'debts_you_owe' => 'Le debes a',

    'statistics_contacts' => 'Contactos',
    'statistics_activities' => 'Actividades',
    'statistics_gifts' => 'Regalos',

    'reminders_next_months' => 'Eventos en los próximos 3 meses',
    'reminders_none' => 'Ningún recordatorio este mes.',

    'product_changes' => 'Cambios del producto',
    'product_view_details' => 'Ver detalles',
];
