<?php
namespace Aws\MarketplaceMetering\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWSMarketplace Metering** service.
 */
class MarketplaceMeteringException extends AwsException {}
