<?php
namespace Aws\ChimeSDKVoice\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Chime SDK Voice** service.
 */
class ChimeSDKVoiceException extends AwsException {}
