<?php
namespace Aws\ManagedBlockchain\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Managed Blockchain** service.
 */
class ManagedBlockchainException extends AwsException {}
