<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'ߊߛߊ߲ߛߌߦߐ߲߫ ߕߌ߲',
  'AD' => 'ߊ߲ߘߐߙ',
  'AE' => 'ߋߡߌߙߊߕ ߊߙߊߓߎ߫ ߘߍ߬ߣߍ߲',
  'AF' => 'ߊߝߎߜ߭ߊߣߌߛߑߕߊ߲߫',
  'AG' => 'ߊ߲ߕߌߞߎߥߊ߫ ߣߌ߫ ߓߊߙߑߓߎߘߊ߫',
  'AI' => 'ߊ߲ߞߎ߳ߟߊ߫',
  'AL' => 'ߊߟߑߓߊߣߌ߫',
  'AM' => 'ߊߙߑߡߋߣߌ߫',
  'AO' => 'ߊ߲ߜߏߟߊ߫',
  'AQ' => 'ߊ߲ߕߊߙߑߛߕߌߞ',
  'AR' => 'ߊߙߑߖ߭ߊ߲ߕߌߣ',
  'AS' => 'ߛߊߡߏߥߊ߫ ߊߡߋߙߞߌߞߊ',
  'AT' => 'ߏߕߑߙߌߛ',
  'AU' => 'ߐߛߑߕߙߊߟߌ߫',
  'AW' => 'ߊߙߎߓߊ߫',
  'AX' => 'ߊߟߊ߲ߘ ߕߌ߲',
  'AZ' => 'ߊߖߊߙߑߓߊߦߌߖߊ߲',
  'BA' => 'ߓߐߛߑߣߌ߫-ߍߙߑߖ߭ߋߜ߭ߏߝ߭ߌߣ',
  'BB' => 'ߓߊߙߑߓߊߘ',
  'BD' => 'ߓߊ߲ߜ߭ߑߟߊߘߍߛ',
  'BE' => 'ߓߍߟߑߖ߭ߌߞ',
  'BF' => 'ߓߙߎߞߌߣߊ߫ ߝߊ߬ߛߏ߫',
  'BG' => 'ߓߌߟߑߜ߭ߊ߯ߙߌ߫',
  'BH' => 'ߓߤߊ߬ߙߊߦߌ߬ߣ',
  'BI' => 'ߓߎߙߎ߲ߘߌ߫',
  'BJ' => 'ߓߋߣߍ߲߫',
  'BL' => 'ߛߍ߲ߕ-ߓߌߙߑߕߟߋߡߌ߫',
  'BM' => 'ߓߍߙߑߓߎߘ',
  'BN' => 'ߓߙߎߣߋ߫',
  'BO' => 'ߓߏߟߝ߭ߌ߫',
  'BQ' => 'ߤߏߟߊ߲ߘ ߞߊߙߌߓߋ߫',
  'BR' => 'ߓߙߋߖ߭ߌߟ',
  'BS' => 'ߓߤߊߡߊߛ',
  'BT' => 'ߓߎߕߊ߲߫',
  'BW' => 'ߓߐߛߎߥߣߊ߫',
  'BY' => 'ߓߌߟߏߙߌߛ',
  'BZ' => 'ߓߋߟߌߖ߭',
  'CA' => 'ߞߣߊߘߊ߫',
  'CC' => 'ߞߏߞߏ߫ ߕߌ߲',
  'CD' => 'ߞߏ߲߬ߜ߭ߏ߫-ߞߌ߲ߛߊߛߊ߫',
  'CF' => 'ߕߊ߲ߓߊ߲-ߝߘߊ߬ߝߌ߲߬ߠߊ߫ ߞߊ߲ߓߍ߲',
  'CG' => 'ߞߏ߲߬ߜ߭ߏ߫-ߓߙߊߖ߭ߊ߫',
  'CH' => 'ߛߎߥߌߛ',
  'CI' => 'ߜߋ߲-ߞߐ߰ߖߌ߬ߘߊ',
  'CK' => 'ߞߎߞ ߕߌ߲',
  'CL' => 'ߛ߭ߟߌ߫',
  'CM' => 'ߞߊߡߋߙߎ߲',
  'CN' => 'ߛߌߣ',
  'CO' => 'ߞߏߟߐ߲ߓߌ߫',
  'CR' => 'ߞߐߛߑߕߊ߫ ߙߌߞߊ߫',
  'CU' => 'ߞߎ߳ߓߊ߫',
  'CV' => 'ߜߙߋߞߎ߲߫-ߝߙߌߛߌ߫',
  'CW' => 'ߞߎߙߛߊߏ߫',
  'CX' => 'ߞߙߌߛߑߕߌߡߊ߫ ߕߌ߲',
  'CY' => 'ߛߌߔߑߙߎ߫',
  'CZ' => 'ߗߍߞ',
  'DE' => 'ߊߟߑߡߊ߲ߘߎ߯',
  'DG' => 'ߖߋߜ߭ߏ߫-ߜ߭ߊߙߑߛߌߦߊ߫',
  'DJ' => 'ߖߌߓߎߕߌ߫',
  'DK' => 'ߘߊߣߌߡߊߙߑߞ',
  'DM' => 'ߘߏߡߣߌߞ',
  'DO' => 'ߘߏߡߣߌߞ ߞߊ߲ߓߍ߲',
  'DZ' => 'ߊߟߑߖ߭ߋߙߌ߫',
  'EA' => 'ߛߋߎߕߊ߫ ߣߌ߫ ߡߋߟߌߣߊ߫',
  'EC' => 'ߕߍߡߊߓߊ߲߮',
  'EE' => 'ߋߛߑߕߏߣߌ߫',
  'EG' => 'ߋߖ߭ߌߔߑߕ',
  'EH' => 'ߞߌ߲߬ߢߍ߬ߞߏ߲ߞߏ߫ ߕߟߋ߬ߓߋ',
  'ER' => 'ߋߙߕߌߙߋ߫',
  'ES' => 'ߊߛߌߔߊ߲߫',
  'ET' => 'ߋߗߏߔߌ߫',
  'FI' => 'ߝߍ߲ߟߊ߲ߘ',
  'FJ' => 'ߝߖߌ߫',
  'FK' => 'ߡߊߟߎ߲ߌ߲߫ ߕߌ߲',
  'FM' => 'ߡߌߞߙߏߣߋߖ߭ߌ߫',
  'FO' => 'ߝߋߙߏߦߋ߫ ߕߌ߲',
  'FR' => 'ߝߊ߬ߙߊ߲߬ߛߌ߫',
  'GA' => 'ߜ߭ߊߓߐ߲߫',
  'GB' => 'ߡߊ߲߬ߛߊ߬ߟߊ߫ ߟߊߘߍ߬ߣߍ߲',
  'GD' => 'ߜ߭ߙߋߣߊߘ',
  'GE' => 'ߖ߭ߋߐߙߑߖ߭ߌ߫',
  'GF' => 'ߝߊ߲߬ߙߊ߲߬ߛߌ߫ ߜ߭ߎ߳ߦߊߣ',
  'GG' => 'ߜ߭ߋߙߑߣߋߖ߭ߌ߫',
  'GH' => 'ߜ߭ߊ߯ߣߊ߫',
  'GI' => 'ߜ߭ߌߓߙߊߟߑߕߊߙ',
  'GL' => 'ߜ߭ߎߙߎ߲ߟߊ߲ߘ',
  'GM' => 'ߜ߭ߊ߲ߓߌ߫',
  'GN' => 'ߖߌ߬ߣߍ߫',
  'GP' => 'ߜ߭ߎߥߊߘߋߟߎߔ',
  'GQ' => 'ߕߍߡߊߓߊ߲߮-ߖߌ߬ߣߍ߫',
  'GR' => 'ߜ߭ߙߍ߬ߞߌ߬',
  'GS' => 'ߖ߭ߐߙߑߖ߭ߌ߫ ߥߙߏ߬ߘߎ߮ ߣߌ߫ ߛߊ߲ߘߎߥߌߛ ߕߌ߲',
  'GT' => 'ߜ߭ߎߥߊߕߋߡߟߊ߫',
  'GU' => 'ߜ߭ߎߥߊߡ',
  'GW' => 'ߖߌ߬ߣߍ߫ ߓߌߛߊߥߏ߫',
  'GY' => 'ߜ߭ߎߦߊߣ',
  'HK' => 'ߛߌߣ ߕߌ߲߬ߞߎߘߎ߲߫ ߡߊߡߙߊ߬ߣߍ߲ ߤߐ߲ߞߐ߲߫',
  'HN' => 'ߤߎ߲ߘߎߙߊ߫',
  'HR' => 'ߞߙߏߥߊߛߌ߫',
  'HT' => 'ߤߊߦߕߌ߫',
  'HU' => 'ߤߐ߲ߜ߭ߙߌ߫',
  'IC' => 'ߞߣߊߙߌ߫ ߕߌ߲',
  'ID' => 'ߍ߲ߘߣߏߖ߭ߌ߫',
  'IE' => 'ߌߙߑߟߊ߲ߘ',
  'IL' => 'ߌߛߑߙߊߍߟ',
  'IM' => 'ߡߊ߲߯ ߕߌ߲',
  'IN' => 'ߌߘߎ߬',
  'IO' => 'ߓߙߌߕߊ߲ߓߊ߫ ߟߊ߫ ߌ߲ߘߎ߫ ߟߌ߲ߓߊ߲ ߞߣߍ',
  'IQ' => 'ߌߙߊߞߌ߬',
  'IR' => 'ߌߙߊ߲߫',
  'IS' => 'ߌߛߑߟߊߘ',
  'IT' => 'ߌߕߊߟߌ߫',
  'JE' => 'ߖߋߙߑߖ߭ߌ߫',
  'JM' => 'ߖ߭ߡߊߦߌߞ',
  'JO' => 'ߖߐߙߑߘߊߣߌ߫',
  'JP' => 'ߖ߭ߊߔߐ߲߫',
  'KE' => 'ߞߋߣߌߦߊ߫',
  'KG' => 'ߞߌߙߑߜ߭ߌߛߑߕߊ߲߫',
  'KH' => 'ߞߊ߲ߓߐߘߑߖ',
  'KI' => 'ߞߙߌߓߊߕߌ߫',
  'KM' => 'ߞߡߐߙ',
  'KN' => 'ߛߍ߲ߕ-ߞߙߌߛߑߕߐߝ ߣߌ߫ ߢߝ߭ߋ߫',
  'KP' => 'ߞߐ߬ߘߎ߮ ߞߏ߯ߙߋ߫',
  'KR' => 'ߕߟߋ߬ߓߋ ߞߏ߯ߙߋ߫',
  'KW' => 'ߞߎ߬ߥߊ߬ߕ',
  'KY' => 'ߓߊ߲߬ߓߊ߬-ߕߌ߲',
  'KZ' => 'ߞߖ߭ߊߞߌߛߑߕߊ߲߫',
  'LA' => 'ߟߊߐߛ',
  'LB' => 'ߟߌߓߊ߲߫',
  'LC' => 'ߛߍ߲ߕ-ߟߎ߳ߛߌ߫',
  'LI' => 'ߟߎߛߑߕߊ߲ߛߑߕߍ߲߫',
  'LK' => 'ߛߙߌߟߊ߲ߞߊ߫',
  'LR' => 'ߟߌߓߋߙߌߦߊ߫',
  'LS' => 'ߟߋߛߕߏ߫',
  'LT' => 'ߟߎߕߎ߳ߦߊߣߌ߫',
  'LU' => 'ߟߎߜ߭ߑߛߊ߲ߓߎ߯ߙ',
  'LV' => 'ߟߋߕߏߣߌ߫',
  'LY' => 'ߟߓߌ߫',
  'MA' => 'ߡߊ߬ߙߐߞߎ߬',
  'MC' => 'ߡߏߣߊߞߏ߫',
  'MD' => 'ߡߐߟߑߘߊߝ߭ߌ߫',
  'ME' => 'ߡߐ߲ߕߣߋߜ߭ߙߏ߫',
  'MF' => 'ߛߍ߲ߕ-ߡߊߙߑߕߍ߲߫',
  'MG' => 'ߡߘߊߜ߭ߛߑߞߊ߯ߙ',
  'MH' => 'ߡߊߙߑߛߊߟ ߕߌ߲',
  'MK' => 'ߞߐ߬ߘߎ߮ ߡߊߛߋߘߏߣߌ߫',
  'ML' => 'ߡߊ߬ߟߌ߬',
  'MM' => 'ߡߌߦߊߡߊ߯ߙ ( ߓߙߌߡߊߣߌ߫ )',
  'MN' => 'ߡߐ߲ߜ߭ߐߟߌ߫',
  'MO' => 'ߛߌߣ ߕߌ߲߬ߞߎߘߎ߲߫ ߡߊߡߙߊ߬ߣߍ߲ ߡߞߊߥߏ߫',
  'MP' => 'ߡߊߙߌߦߊߣ ߞߐ߬ߘߎ߮ ߕߌ߲',
  'MQ' => 'ߡߊߙߑߕߣߌߞ',
  'MR' => 'ߡߏߙߌߕߊߣߌ߫',
  'MS' => 'ߡߐ߲ߗߋߙߊ߫',
  'MT' => 'ߡߊߟߑߕ',
  'MU' => 'ߡߏߙߌߛ',
  'MV' => 'ߡߊߟߑߘߌߝ߭',
  'MW' => 'ߡߟߊߥߌ߫',
  'MX' => 'ߡߍߞߑߛߌߞ',
  'MY' => 'ߡߊߟߍߘߎ߯',
  'MZ' => 'ߡߏߖ߭ߊ߲ߓߌߞ',
  'NA' => 'ߣߊߡߌ߲ߓߌ߫',
  'NC' => 'ߞߊߟߋߘߏߣߌ߫-ߞߎߘߊ߫',
  'NE' => 'ߖߋ߬ߟߌ߬ߓߊߘߎ߯',
  'NF' => 'ߣߐߙߑߝߐߟߑߞ',
  'NG' => 'ߖߋ߬ߟߌ߬ߓߊ߬ߟߊ߫',
  'NI' => 'ߣߌߞߙߊߜ߭ߎߥߊ߫',
  'NL' => 'ߤߏߟߊ߲ߘ',
  'NO' => 'ߣߐߙߑߝ߭ߍߖ',
  'NP' => 'ߣߋߔߊߟ',
  'NR' => 'ߣߏ߯ߙߎ߫',
  'NU' => 'ߣߎ߳ߋ߫',
  'NZ' => 'ߖ߭ߋߟߊ߲ߘߌ߫-ߞߎߘߊ߫',
  'OM' => 'ߏߡߊ߲߫',
  'PA' => 'ߔߣߊߡߊ߫',
  'PE' => 'ߔߋߙߎ߫',
  'PF' => 'ߝߊ߬ߙߊ߲߬ߛߌ߫ ߔߏߟߌߣߋߖ߭ߌ߫',
  'PG' => 'ߡߊߡߎߥߊߖ߭ߌ߫ ߖߌ߬ߣߍ߬-ߞߎߘߊ߫',
  'PH' => 'ߝߟߌߔߌ߲ߣ',
  'PK' => 'ߔߊߞߌߛߑߕߊ߲߫',
  'PL' => 'ߔߏߟߐߢ',
  'PM' => 'ߛߍ߲ߕ-ߔߍ߯ߙ ߣߌ߫ ߡߌ߲ߞߋߟߐ߲߫',
  'PN' => 'ߔߌߕߑߞߍ߲ ߕߌ߲',
  'PR' => 'ߔߐߙߑߕߏ߫-ߙߌߞߏ߫',
  'PS' => 'ߔߊߟߍߛߑߕߌߣ ߞߣߍ',
  'PT' => 'ߔߐߙߑߕߎߜ߭ߊߟ',
  'PW' => 'ߔߟߊߐߛ',
  'PY' => 'ߔߙߊߜ߭ߏߦߋ߫',
  'QA' => 'ߞߊߕߊ߯ߙ',
  'RE' => 'ߟߊ߬ߘߍ',
  'RO' => 'ߙߎߡߊߣߌ߫',
  'RS' => 'ߛߍߙߑߓߌ߫',
  'RU' => 'ߌߙߌ߬ߛߌ߫',
  'RW' => 'ߙߎߥߊ߲ߘߊ߫',
  'SA' => 'ߛߎ߰ߘߎ߬ߟߊ߫-ߡߊ߲߬ߛߊ߬ߟߊ',
  'SB' => 'ߛߊߟߏߡߐ߲߫ ߕߌ߲',
  'SC' => 'ߛߋߦߌߛߍߟ',
  'SD' => 'ߛߎߘߊ߲߫',
  'SE' => 'ߛߎߥߍߘ',
  'SG' => 'ߛߌ߲ߜ߭ߊߔߎߙ',
  'SH' => 'ߛߍ߲ߕ-ߋߟߍߣ',
  'SI' => 'ߛߑߟߏߝ߭ߋߣߌ߫',
  'SJ' => 'ߛߊߟߑߓߊߙ ߣߌ߫ ߖ߭ߊ߲ ߡߊߦߍ߲߫',
  'SK' => 'ߛߑߟߏߝ߭ߊߞߌ߫',
  'SL' => 'ߛߙߊ߬ߟߏ߲߫',
  'SM' => 'ߛߍߕ-ߡߊߙߍ߲߫',
  'SN' => 'ߛߣߍ߬ߜߊ߯ߟߌ߫',
  'SO' => 'ߛߏߡߊߟߌ߫',
  'SR' => 'ߛߎߙߑߣߊߡ',
  'SS' => 'ߥߙߏ߬ߘߎ߮ ߛߎ߬ߘߊ߲߫',
  'ST' => 'ߛߊߥߕߏߡߋ߫ ߣߌ߫ ߔߑߙߍ߲ߛߌߔ',
  'SV' => 'ߛߊߟߑߝ߭ߊߘߐߙ',
  'SX' => 'ߛߍ߲ߕ-ߡߊߙߑߕߍ߲߫ ( ߤߏߟߊ߲ߘ ߝߊ߲߭ߝߍ߬ )',
  'SY' => 'ߛߙߌ߫',
  'SZ' => 'ߒߛߎߥߊߕߣߌ߫',
  'TA' => 'ߞߎ߲ߓߊ߫ ߕߑߙߌߛߑߕߊ߫',
  'TC' => 'ߕߎߙߑߞߌ߫ ߣߌ߫ ߞߊߦߌߞ',
  'TD' => 'ߗߊߘ',
  'TF' => 'ߝߊ߬ߙߊ߲߬ߛߌ߫ ߘߎ߰ߞߟߏ ߓߊߙߌ ߘߐ߫',
  'TG' => 'ߕߜ߭ߏ߫',
  'TH' => 'ߕߊߦߌߘߎ߯',
  'TJ' => 'ߕߊߖߞߌߛߑߕߊ߲߫',
  'TK' => 'ߕߏߞߋߟߊߏ߫',
  'TL' => 'ߕߌߡߐߙ ߕߟߋ߬ߓߐ߬ߝߊ߲',
  'TM' => 'ߕߎߙߑߞߌߡߋߣߌߛߑߕߊ߲߫',
  'TN' => 'ߕߎߣߖ߭ߌ߫',
  'TO' => 'ߕߏ߲ߜ߭ߊ߫',
  'TR' => 'ߕߎߙߑߞߌ߫',
  'TT' => 'ߕߙߌߣߌߕߋ߫ ߣߌ߫ ߕߏߓߊߜ߭ߏ߫',
  'TV' => 'ߕߎߝ߭ߊߟߎ߫',
  'TW' => 'ߕߊߦߌߥߊ߲߫',
  'TZ' => 'ߕߊ߲ߖ߭ߊߣߌ߫',
  'UA' => 'ߎ߳ߞߑߙߍߣ',
  'UG' => 'ߎߜ߭ߊ߲ߘߊ߫',
  'UM' => 'ߞߊ߬ߝߏ߫ ߘߍ߬ߣߍ߲ ߘߌߣߍ߲߫ ߕߌ߲߫ ߡߊߕߊ߯ߣߍ߲',
  'US' => 'ߞߊ߬ߝߏ߫ ߘߍ߬ߣߍ߲',
  'UY' => 'ߎ߳ߙߑߜ߭ߋߦߌ߫',
  'UZ' => 'ߎߖ߭ߑߓߋߞߌߛߑߕߊ߲߫',
  'VA' => 'ߝ߭ߊߕߌߞߊ߲߫ ߞߊ߬ߝߏ',
  'VC' => 'ߛߍ߲ߕ-ߝ߭ߍߛߊ߲ ߜ߭ߙߋߣߊߘߌ߫',
  'VE' => 'ߝ߭ߣߋߖ߭ߎߦߋߟߊ߫',
  'VG' => 'ߓߙߌߕߊ߲ߓߊ߫ ߕߌ߲߫ ߞߊߓߊ߲',
  'VI' => 'ߞߊ߬ߝߏ߫ ߘߍ߬ߣߍ߲ ߕߌ߲߫ ߞߊߓߊ߲߫',
  'VN' => 'ߝ߭ߌߦߍߕߑߣߊߡ',
  'VU' => 'ߝ߭ߊߣߎߦߊߕߎ߫',
  'WF' => 'ߥߊߟߌߛߌ߫ ߣߌ߫ ߝߕߎߣߊ߫',
  'WS' => 'ߛߊߡߏߥߊ߫',
  'XK' => 'ߞߛߏߝ߭ߏ߫',
  'YE' => 'ߦߡߊߣߌ߲߫',
  'YT' => 'ߡߊߦߐߕ',
  'ZA' => 'ߥߙߏ߬ߘߎ߮ ߝߘߊ߬ߝߌ߲߬ߠߊ߫',
  'ZM' => 'ߖ߭ߊ߲ߓߌ߫',
  'ZW' => 'ߖ߭ߌ߲ߓߊߓߏߦߋ߫',
);
