<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  223200 => 'Orange',
  2232079 => 'Sotelma',
  223217 => 'Sotelma',
  2235 => 'Atel',
  2236 => 'Sotelma',
  2237 => 'Orange',
  22382 => 'Orange',
  22383 => 'Orange',
  22384 => 'Orange',
  22389 => 'Sotelma',
  22390 => 'Orange',
  22391 => 'Orange',
  22392 => 'Orange',
  22393 => 'Orange',
  22394 => 'Orange',
  22395 => 'Sotelma',
  22396 => 'Sotelma',
  22397 => 'Sotelma',
  22398 => 'Sotelma',
  22399 => 'Sotelma',
);
