<?php
namespace Aws\MediaConvert\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Elemental MediaConvert** service.
 */
class MediaConvertException extends AwsException {}
