<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  3851 => 'Zagreb',
  38520 => 'Dubrovnik-Neretva',
  38521 => 'Split-Dalmatia',
  38522 => 'Šibenik-Knin',
  38523 => 'Zadar',
  38531 => 'Osijek-Baranja',
  38532 => 'Vukovar-Srijem',
  38533 => 'Virovitica-Podravina',
  38534 => 'Požega-Slavonia',
  38535 => 'Brod-Posavina',
  38540 => 'Međimurje',
  38542 => 'Varaždin',
  38543 => 'Bjelovar-Bilogora',
  38544 => 'Sisak-Moslavina',
  38547 => 'Karlovac',
  38548 => 'Koprivnica-Križevci',
  38549 => 'Krapina-Zagorje',
  38551 => 'Primorsko-goranska',
  38552 => 'Istra',
  38553 => 'Lika-Senj',
);
