<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  37433 => 'Team Telecom Armenia',
  37441 => 'Ucom',
  37443 => 'Team Telecom Armenia',
  37444 => 'Ucom',
  37449 => 'VivaCell-MTS',
  3745 => 'Ucom',
  3747 => 'VivaCell-MTS',
  37488 => 'VivaCell-MTS',
  37491 => 'Team Telecom Armenia',
  37493 => 'VivaCell-MTS',
  37494 => 'VivaCell-MTS',
  37495 => 'Ucom',
  37496 => 'Team Telecom Armenia',
  37497 => 'Team Telecom Armenia',
  37498 => 'VivaCell-MTS',
  37499 => 'Team Telecom Armenia',
);
