<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'How was your day? You can rate it once a day.',
    'journal_come_back' => 'Thanks. Come back tomorrow to rate your day again.',
    'journal_description' => 'Note: the journal lists both manual journal entries, and automatic entries like Activities done with your contacts. While you can delete journal entries manually, you’ll have to delete the activity directly on the contact page.',
    'journal_add' => 'Add a journal entry',
    'journal_edit' => 'Edit a journal entry',
    'journal_empty' => 'Empty journal',
    'journal_created_at' => 'Created at {date}',
    'journal_created_automatically' => 'Created automatically',
    'journal_entry_type_journal' => 'Journal entry',
    'journal_entry_type_activity' => 'Activity',
    'journal_entry_rate' => 'You rated your day.',
    'journal_add_comment' => 'Care to add a comment (optional)?',
    'journal_show_comment' => 'Show comment',
    'entry_delete_success' => 'The journal entry has been successfully deleted.',
    'journal_add_title' => 'Title (optional)',
    'journal_add_date' => 'Date',
    'journal_add_post' => 'Entry',
    'journal_add_cta' => 'Save',
    'journal_blank_cta' => 'Add your first journal entry',
    'journal_blank_description' => 'The journal lets you write events that happened to you, and remember them.',
    'delete_confirmation' => 'Are you sure you want to delete this journal entry?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
