<?php
namespace Aws\MediaPackageVod\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Elemental MediaPackage VOD** service.
 */
class MediaPackageVodException extends AwsException {}
