<?php
// This file was auto-generated from sdk-root/src/data/sms/2016-10-24/paginators-1.json
return [ 'pagination' => [ 'GetConnectors' => [ 'input_token' => 'nextToken', 'limit_key' => 'maxResults', 'output_token' => 'nextToken', 'result_key' => 'connectorList', ], 'GetReplicationJobs' => [ 'input_token' => 'nextToken', 'limit_key' => 'maxResults', 'output_token' => 'nextToken', 'result_key' => 'replicationJobList', ], 'GetReplicationRuns' => [ 'input_token' => 'nextToken', 'limit_key' => 'maxResults', 'output_token' => 'nextToken', 'result_key' => 'replicationRunList', ], 'GetServers' => [ 'input_token' => 'nextToken', 'limit_key' => 'maxResults', 'output_token' => 'nextToken', 'result_key' => 'serverList', ], ],];
