<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  9592 => 'MPT',
  9593 => 'MPT',
  95940 => 'MPT',
  95941 => 'MPT',
  95942 => 'MPT',
  95943 => 'MPT',
  95944 => 'MPT',
  95945 => 'MPT',
  95947 => 'MPT',
  95949 => 'MPT',
  9595 => 'MPT',
  9596 => 'Mytel',
  9597 => 'Telenor',
  95973 => 'MPT',
  95981 => 'MPT',
  95983 => 'MPT',
  95984 => 'MPT',
  95985 => 'MPT',
  95986 => 'MPT',
  95987 => 'MPT',
  95988 => 'MPT',
  95989 => 'MPT',
  95991 => 'MPT',
  95994 => 'Ooredoo',
  95995 => 'Ooredoo',
  95996 => 'Ooredoo',
  95997 => 'Ooredoo',
  95998 => 'Ooredoo',
);
