<?php
namespace Aws\EC2InstanceConnect\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS EC2 Instance Connect** service.
 */
class EC2InstanceConnectException extends AwsException {}
