<?php
namespace Aws\FraudDetector\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Fraud Detector** service.
 */
class FraudDetectorException extends AwsException {}
