<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'title' => '更新日志',
    'note' => '注：很抱歉，当前页面只支持英文展示。',
];
