<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  24104 => 'Airtel',
  24105 => 'Moov',
  24106 => 'Libertis',
  24107 => 'Airtel',
  24120 => 'Libertis',
  24121 => 'Libertis',
  24122 => 'Libertis',
  24123 => 'Libertis',
  24124 => 'Libertis',
  24125 => 'Libertis',
  24126 => 'Libertis',
  24127 => 'Libertis',
  2413 => 'Libertis',
  2414 => 'Airtel',
  2415 => 'Moov',
  2416 => 'Libertis',
  24165 => 'Moov',
  2417 => 'Airtel',
);
