<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => 'Erinnerung für :contact',
    'greetings' => 'Hallo :username',
    'want_reminded_of' => 'Sie wollten erinnert werden :reason',
    'for' => 'Für: :name',
    'comment' => 'Kommentar: :comment',
    'footer_contact_info' => 'Ergänze, betrachte, vervollständige und ändere Informationen zu diesem Kontakt:',
    'footer_contact_info2' => 'Siehe :name’s profile',
    'footer_contact_info2_link' => 'Siehe :name Profil',

    'notification_subject_line' => 'Du hast ein bevorstehendes Ereignis',
    'notification_description' => 'In :count Tagen (am :date), findet folgendes Ereignis statt:',

    'stay_in_touch_subject_line' => 'Mit :name in Kontakt bleiben',
    'stay_in_touch_subject_description' => 'Sie wollten jeden :frequency Tag erinnert werden, um in Kontakt zu bleiben mit :name .| 
Sie wollten alle :frequency Tage erinnert werden um in Kontakt zu bleiben mit :name .',

    'notifications_whoops' => 'Hoppla!',
    'notifications_hello' => 'Hallo!',
    'notifications_regards' => 'Grüße',
    'notifications_footer' => 'Wenn Sie Probleme beim Klicken auf die Schaltfläche ":actionText" haben, kopieren Sie einfach die folgende URL in die Adresszeile Ihres Webbrowsers: [:actionURL](:actionURL)',
    'notifications_rights' => 'Alle Rechte vorbehalten',

    'confirmation_email_title' => 'Monica – E-Mail-Verifikation',
    'confirmation_email_intro'=> 'Um Ihre E-Mail-Adresse zu validieren, klicken Sie bitte auf den untenstehenden Button',
    'confirmation_email_button' => 'E-Mail-Adresse bestätigen',
    'confirmation_email_bottom' => 'Wenn Sie kein Konto erstellt haben, ist keine weitere Aktion erforderlich.',

    'password_reset_title' => 'Monica – Passwort-Benachrichtigung zurücksetzen',
    'password_reset_intro' => 'Sie erhalten diese E-Mail, weil wir eine Anfrage zum Zurücksetzen des Passworts für Ihr Konto erhalten haben.',
    'password_reset_button' => 'Passwort zurücksetzen',
    'password_reset_expiration' => 'Dieser Link zum Zurücksetzen des Passworts läuft in :count Minuten ab.',
    'password_reset_bottom' => 'Wenn Sie keine Passwortzurücksetzung angefordert haben, ist keine weitere Aktion erforderlich.',

    'invitation_title' => 'Monica – Du wurdest von :name eingeladen',
    'invitation_intro' => 'Sie wurden von :name (:email) eingeladen, um Monica zu verwenden, ein Personal Relationship Management Tool.',
    'invitation_link' => 'Um die Einladung anzunehmen, klicken Sie auf den folgenden Link:',
    'invitation_button' => 'Einladung annehmen',
    'invitation_expiration' => 'Dieser Link läuft in :count Tagen ab.',

    'export_title' => 'Ihr Export ist fertig',
    'export_description' => 'Sie haben einen Datenexport am :date angefordert. Dieser ist nun zum Download bereit.',
    'export_download' => 'Export herunterladen',

];
