<?php

namespace Doctrine\DBAL\Platforms;

/**
 * Provides the behavior, features and SQL dialect of the PostgreSQL 9.4+ database platform.
 *
 * @deprecated Use {@see PostgreSQLPlatform} instead.
 */
class PostgreSQL94Platform extends PostgreSQLPlatform
{
}
