<?php
// This file was auto-generated from sdk-root/src/data/resource-explorer-2/2022-07-28/paginators-1.json
return [ 'pagination' => [ 'ListIndexes' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Indexes', ], 'ListIndexesForMembers' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Indexes', ], 'ListSupportedResourceTypes' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ResourceTypes', ], 'ListViews' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Views', ], 'Search' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'Resources', ], ],];
