<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'Popřát k narozeninám',
    'type_phone_call' => 'Zavolat',
    'type_lunch' => 'Oběd s',
    'type_hangout' => 'Setkání s',
    'type_email' => 'Email',
    'type_birthday_kid' => 'Wish happy birthday to the child of',
];
