<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  68820 => 'Funafuti',
  68822 => 'Niulakita',
  68823 => 'Nui',
  68824 => 'Nukufetau',
  68825 => 'Nukulaelae',
  68826 => 'Nanumea',
  68827 => 'Nanumaga',
  68828 => 'Niutao',
  68829 => 'Vaitupu',
);
