<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AE' => '阿拉伯聯合酋長國',
  'AG' => '安提瓜和巴布達',
  'AW' => '阿魯巴',
  'AZ' => '亞塞拜疆',
  'BA' => '波斯尼亞和黑塞哥維那',
  'BB' => '巴巴多斯',
  'BF' => '布基納法索',
  'BI' => '布隆迪',
  'BJ' => '貝寧',
  'BL' => '聖巴泰勒米',
  'BW' => '博茨瓦納',
  'BZ' => '伯利茲',
  'CC' => '科科斯 (基林) 群島',
  'CI' => '科特迪瓦',
  'CR' => '哥斯達黎加',
  'CV' => '佛得角',
  'CY' => '塞浦路斯',
  'DJ' => '吉布提',
  'DO' => '多米尼加共和國',
  'EC' => '厄瓜多爾',
  'ER' => '厄立特里亞',
  'ET' => '埃塞俄比亞',
  'GA' => '加蓬',
  'GD' => '格林納達',
  'GE' => '格魯吉亞',
  'GH' => '加納',
  'GM' => '岡比亞',
  'GS' => '南佐治亞島與南桑威奇群島',
  'GT' => '危地馬拉',
  'GW' => '幾內亞比紹',
  'GY' => '圭亞那',
  'HN' => '洪都拉斯',
  'HR' => '克羅地亞',
  'IM' => '馬恩島',
  'IT' => '意大利',
  'KE' => '肯尼亞',
  'KM' => '科摩羅',
  'KN' => '聖基茨和尼維斯',
  'LA' => '老撾',
  'LC' => '聖盧西亞',
  'LI' => '列支敦士登',
  'LR' => '利比里亞',
  'LS' => '萊索托',
  'ME' => '黑山',
  'ML' => '馬里',
  'MR' => '毛里塔尼亞',
  'MS' => '蒙特塞拉特',
  'MT' => '馬耳他',
  'MU' => '毛里裘斯',
  'MV' => '馬爾代夫',
  'MW' => '馬拉維',
  'MZ' => '莫桑比克',
  'NE' => '尼日爾',
  'NG' => '尼日利亞',
  'NR' => '瑙魯',
  'PF' => '法屬波利尼西亞',
  'PG' => '巴布亞新畿內亞',
  'PN' => '皮特凱恩島',
  'PS' => '巴勒斯坦領土',
  'QA' => '卡塔爾',
  'RW' => '盧旺達',
  'SA' => '沙地阿拉伯',
  'SB' => '所羅門群島',
  'SC' => '塞舌爾',
  'SI' => '斯洛文尼亞',
  'SJ' => '斯瓦爾巴特群島及揚馬延島',
  'SL' => '塞拉利昂',
  'SM' => '聖馬力諾',
  'SO' => '索馬里',
  'SR' => '蘇里南',
  'ST' => '聖多美和普林西比',
  'SZ' => '斯威士蘭',
  'TC' => '特克斯和凱科斯群島',
  'TD' => '乍得',
  'TF' => '法屬南部領地',
  'TO' => '湯加',
  'TT' => '千里達和多巴哥',
  'TV' => '圖瓦盧',
  'TZ' => '坦桑尼亞',
  'VC' => '聖文森特和格林納丁斯',
  'VG' => '英屬維爾京群島',
  'VI' => '美屬維爾京群島',
  'VU' => '瓦努阿圖',
  'YE' => '也門',
  'YT' => '馬約特',
  'ZM' => '贊比亞',
  'ZW' => '津巴布韋',
);
