<?php
namespace Aws\Translate\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Translate** service.
 */
class TranslateException extends AwsException {}
