<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'Souhait d’anniversaire pour',
    'type_phone_call' => 'Appeler',
    'type_lunch' => 'Manger avec',
    'type_hangout' => 'Aller voir',
    'type_email' => 'Envoyer un email à',
    'type_birthday_kid' => 'Souhaiter un joyeux anniversaire à l’enfant de',
];
