<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'dashboard_blank_title' => 'Καλώς ήρθατε στο λογαριασμό σας!',
    'dashboard_blank_description' => 'Η εφαρμογή Monica είναι το μέρος για να οργανώσετε όλες τις αλληλεπιδράσεις που έχετε με τους ανθρώπους που σας ενδιαφέρουν.',
    'dashboard_blank_cta' => 'Προσθέστε την πρώτη σας επαφή',
    'dashboard_blank_illustration' => 'Εικονογράφηση από τον <a href=":url">Freepik</a>',

    'notes_title' => 'Δεν έχετε σημειώσεις με αστέρι.',

    'tab_recent_calls' => 'Πρόσφατες κλήσεις',
    'tab_favorite_notes' => 'Αγαπημένες σημειώσεις',
    'tab_calls_blank' => 'Δεν έχετε καταγράψει καμία κλήση ακόμα.',
    'tab_debts' => 'Χρέη',
    'tab_debts_blank' => 'Δεν έχετε καταγράψει ακόμη χρέη.',
    'tab_tasks' => 'Εργασίες',
    'tab_tasks_blank' => 'Δεν έχετε ακόμα καμία εργασία.',

    'tasks_add_task_placeholder' => 'Τι είναι αυτή η εργασία;',
    'tasks_tab_your_contacts' => 'Εργασίες που σχετίζονται με τις επαφές σας',
    'tasks_tab_your_tasks' => 'Οι εργασίες σας',
    'tasks_add_note' => 'Πατήστε <kbd>Enter</kbd> για να προσθέσετε την εργασία.',
    'task_add_cta' => 'Προσθήκη Εργασίας',

    'debts_you_owe' => 'Χρωστάτε',

    'statistics_contacts' => 'Επαφές',
    'statistics_activities' => 'Δραστηριότητες',
    'statistics_gifts' => 'Δώρα',

    'reminders_next_months' => 'Γεγονότα τους επόμενους 3 μήνες',
    'reminders_none' => 'Δεν υπάρχουν υπενθυμίσεις για αυτό το μήνα.',

    'product_changes' => 'Αλλαγές προϊόντος',
    'product_view_details' => 'Προβολή λεπτομερειών',
];
