<?php
/**
 * Locale @generated from CLDR version 45.0.0
 * See README.md for more information.
 *
 * @internal
 *
 * Do not modify or use this file directly!
 */

return array (
  'AC' => 'Pulo Ascension',
  'AD' => 'Andora',
  'AE' => 'Uni Émirat Arab',
  'AF' => 'Afganistan',
  'AG' => 'Antigua lan Barbuda',
  'AI' => 'Anguilla',
  'AL' => 'Albani',
  'AM' => 'Arménia',
  'AO' => 'Angola',
  'AQ' => 'Antartika',
  'AR' => 'Argèntina',
  'AS' => 'Samoa Amerika',
  'AT' => 'Ostenrik',
  'AU' => 'Ostrali',
  'AW' => 'Aruba',
  'AX' => 'Kapuloan Alan',
  'AZ' => 'Azerbaijan',
  'BA' => 'Bosnia lan Hèrségovina',
  'BB' => 'Barbadhos',
  'BD' => 'Banggaladésa',
  'BE' => 'Bèlgi',
  'BF' => 'Burkina Faso',
  'BG' => 'Bulgari',
  'BH' => 'Bahrain',
  'BI' => 'Burundi',
  'BJ' => 'Bénin',
  'BL' => 'Saint Barthélémi',
  'BM' => 'Bermuda',
  'BN' => 'Brunéi',
  'BO' => 'Bolivia',
  'BQ' => 'Karibia Walanda',
  'BR' => 'Brasil',
  'BS' => 'Bahamas',
  'BT' => 'Bhutan',
  'BW' => 'Botswana',
  'BY' => 'Bélarus',
  'BZ' => 'Bélisé',
  'CA' => 'Kanada',
  'CC' => 'Kapuloan Cocos (Keeling)',
  'CD' => 'Kongo - Kinshasa',
  'CF' => 'Républik Afrika Tengah',
  'CG' => 'Kongo - Brassaville',
  'CH' => 'Switserlan',
  'CI' => 'Pasisir Gadhing',
  'CK' => 'Kapuloan Cook',
  'CL' => 'Cilé',
  'CM' => 'Kamerun',
  'CN' => 'Tyongkok',
  'CO' => 'Kolombia',
  'CR' => 'Kosta Rika',
  'CU' => 'Kuba',
  'CV' => 'Pongol Verdé',
  'CW' => 'Kurasao',
  'CX' => 'Pulo Natal',
  'CY' => 'Siprus',
  'CZ' => 'Céko',
  'DE' => 'Jérman',
  'DG' => 'Diego Garcia',
  'DJ' => 'Jibuti',
  'DK' => 'Dhènemarken',
  'DM' => 'Dominika',
  'DO' => 'Républik Dominika',
  'DZ' => 'Aljasair',
  'EA' => 'Séuta lan Melila',
  'EC' => 'Ékuadhor',
  'EE' => 'Éstonia',
  'EG' => 'Mesir',
  'EH' => 'Sahara Kulon',
  'ER' => 'Éritréa',
  'ES' => 'Sepanyol',
  'ET' => 'Étiopia',
  'FI' => 'Finlan',
  'FJ' => 'Fiji',
  'FK' => 'Kapuloan Falkland',
  'FM' => 'Féderasi Mikronésia',
  'FO' => 'Kapuloan Faro',
  'FR' => 'Prancis',
  'GA' => 'Gabon',
  'GB' => 'Karajan Manunggal',
  'GD' => 'Grénada',
  'GE' => 'Géorgia',
  'GF' => 'Guyana Prancis',
  'GG' => 'Guernsei',
  'GH' => 'Ghana',
  'GI' => 'Gibraltar',
  'GL' => 'Greenland',
  'GM' => 'Gambia',
  'GN' => 'Guinea',
  'GP' => 'Guadélup',
  'GQ' => 'Guinéa Katulistiwa',
  'GR' => 'Grikenlan',
  'GS' => 'Georgia Kidul lan Kapuloan Sandwich Kidul',
  'GT' => 'Guatémala',
  'GU' => 'Guam',
  'GW' => 'Guinea-Bissau',
  'GY' => 'Guyana',
  'HK' => 'Laladan Administratif Astamiwa Hong Kong',
  'HN' => 'Honduras',
  'HR' => 'Kroasia',
  'HT' => 'Haiti',
  'HU' => 'Honggari',
  'IC' => 'Kapuloan Kanari',
  'ID' => 'Indonésia',
  'IE' => 'Républik Irlan',
  'IL' => 'Israèl',
  'IM' => 'Pulo Man',
  'IN' => 'Indhia',
  'IO' => 'Wilayah Inggris ing Segara Hindia',
  'IQ' => 'Irak',
  'IR' => 'Iran',
  'IS' => 'Èslan',
  'IT' => 'Itali',
  'JE' => 'Jersey',
  'JM' => 'Jamaika',
  'JO' => 'Yordania',
  'JP' => 'Jepang',
  'KE' => 'Kénya',
  'KG' => 'Kirgistan',
  'KH' => 'Kamboja',
  'KI' => 'Kiribati',
  'KM' => 'Komoro',
  'KN' => 'Saint Kits lan Nèvis',
  'KP' => 'Korea Lor',
  'KR' => 'Koréa Kidul',
  'KW' => 'Kuwait',
  'KY' => 'Kapuloan Kéman',
  'KZ' => 'Kasakstan',
  'LA' => 'Laos',
  'LB' => 'Libanon',
  'LC' => 'Santa Lusia',
  'LI' => 'Liktenstén',
  'LK' => 'Sri Lanka',
  'LR' => 'Libèria',
  'LS' => 'Lésotho',
  'LT' => 'Litowen',
  'LU' => 'Luksemburg',
  'LV' => 'Latvia',
  'LY' => 'Libya',
  'MA' => 'Maroko',
  'MC' => 'Monako',
  'MD' => 'Moldova',
  'ME' => 'Montenégro',
  'MF' => 'Santa Martin',
  'MG' => 'Madagaskar',
  'MH' => 'Kapuloan Marshall',
  'MK' => 'Républik Makédonia Lor',
  'ML' => 'Mali',
  'MM' => 'Myanmar (Burma)',
  'MN' => 'Mongolia',
  'MO' => 'Laladan Administratif Astamiwa Makau',
  'MP' => 'Kapuloan Mariana Lor',
  'MQ' => 'Martinik',
  'MR' => 'Mauritania',
  'MS' => 'Monsérat',
  'MT' => 'Malta',
  'MU' => 'Mauritius',
  'MV' => 'Maladéwa',
  'MW' => 'Malawi',
  'MX' => 'Mèksiko',
  'MY' => 'Malaysia',
  'MZ' => 'Mosambik',
  'NA' => 'Namibia',
  'NC' => 'Kalédonia Anyar',
  'NE' => 'Nigér',
  'NF' => 'Pulo Norfolk',
  'NG' => 'Nigéria',
  'NI' => 'Nikaragua',
  'NL' => 'Walanda',
  'NO' => 'Nurwègen',
  'NP' => 'Népal',
  'NR' => 'Nauru',
  'NU' => 'Niue',
  'NZ' => 'Selandia Anyar',
  'OM' => 'Oman',
  'PA' => 'Panama',
  'PE' => 'Peru',
  'PF' => 'Polinesia Prancis',
  'PG' => 'Papua Nugini',
  'PH' => 'Pilipina',
  'PK' => 'Pakistan',
  'PL' => 'Polen',
  'PM' => 'Saint Pièr lan Mikuélon',
  'PN' => 'Kapuloan Pitcairn',
  'PR' => 'Puèrto Riko',
  'PS' => 'Tlatah Palèstina',
  'PT' => 'Portugal',
  'PW' => 'Palau',
  'PY' => 'Paraguay',
  'QA' => 'Katar',
  'RE' => 'Réunion',
  'RO' => 'Ruméni',
  'RS' => 'Sèrbi',
  'RU' => 'Rusia',
  'RW' => 'Rwanda',
  'SA' => 'Arab Saudi',
  'SB' => 'Kapuloan Suleman',
  'SC' => 'Sésèl',
  'SD' => 'Sudan',
  'SE' => 'Swèdhen',
  'SG' => 'Singapura',
  'SH' => 'Saint Héléna',
  'SI' => 'Slovénia',
  'SJ' => 'Svalbard lan Jan Mayen',
  'SK' => 'Slowak',
  'SL' => 'Siéra Léoné',
  'SM' => 'San Marino',
  'SN' => 'Sénégal',
  'SO' => 'Somalia',
  'SR' => 'Suriname',
  'SS' => 'Sudan Kidul',
  'ST' => 'Sao Tomé lan Principé',
  'SV' => 'Èl Salvador',
  'SX' => 'Sint Martén',
  'SY' => 'Suriah',
  'SZ' => 'Swasiland',
  'TA' => 'Tristan da Cunha',
  'TC' => 'Turks lan Kapuloan Kaikos',
  'TD' => 'Chad',
  'TF' => 'Wilayah Prancis nang Kutub Kidul',
  'TG' => 'Togo',
  'TH' => 'Tanah Thai',
  'TJ' => 'Tajikistan',
  'TK' => 'Tokelau',
  'TL' => 'Timor Leste',
  'TM' => 'Turkménistan',
  'TN' => 'Tunisia',
  'TO' => 'Tonga',
  'TR' => 'Turki',
  'TT' => 'Trinidad lan Tobago',
  'TV' => 'Tuvalu',
  'TW' => 'Taiwan',
  'TZ' => 'Tansania',
  'UA' => 'Ukrania',
  'UG' => 'Uganda',
  'UM' => 'Kapuloan AS Paling Njaba',
  'US' => 'Amérika Sarékat',
  'UY' => 'Uruguay',
  'UZ' => 'Usbèkistan',
  'VA' => 'Kutha Vatikan',
  'VC' => 'Saint Vinsen lan Grénadin',
  'VE' => 'Vénésuéla',
  'VG' => 'Kapuloan Virgin Britania',
  'VI' => 'Kapuloan Virgin Amérika',
  'VN' => 'Viètnam',
  'VU' => 'Vanuatu',
  'WF' => 'Wallis lan Futuna',
  'WS' => 'Samoa',
  'XK' => 'Kosovo',
  'YE' => 'Yaman',
  'YT' => 'Mayotte',
  'ZA' => 'Afrika Kidul',
  'ZM' => 'Sambia',
  'ZW' => 'Simbabwe',
);
