<?php
namespace Aws\ServiceDiscovery\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Route 53 Auto Naming** service.
 */
class ServiceDiscoveryException extends AwsException {}
