<?php
namespace Aws\ApplicationInsights\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon CloudWatch Application Insights** service.
 */
class ApplicationInsightsException extends AwsException {}
