<?php

/**
 * ⚠️ Edition not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'message' => '¡Gracias por registrarte! Por favor, revisa tus correos para confirmar tu dirección de correo electrónico.',
    'success' => '¡Has verificado tu cuenta con éxito! Ya puedes iniciar sesión.',
    'again' => 'Debes verificar tu correo electrónico antes de acceder al sitio.
                <br/>Si no has recibido correo de confirmación, revisa tu carpeta de spam.
                <br/>Para obtener un nuevo correo de confirmación, haz <a href=":url" class="alert-link">clic aquí</a>.',
    'resend' => 'Se ha enviado un mensaje de confirmación. Por favor, revisa tu bandeja de entrada.'
];
