<?php
namespace Aws\ConnectCampaignService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AmazonConnectCampaignService** service.
 */
class ConnectCampaignServiceException extends AwsException {}
