<?php
namespace Aws\IoTFleetHub\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Fleet Hub** service.
 */
class IoTFleetHubException extends AwsException {}
