<?php
namespace Aws\NeptuneGraph\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Neptune Graph** service.
 */
class NeptuneGraphException extends AwsException {}
