<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  6753 => 'NCD',
  67542 => 'Madang',
  67545 => 'Sepik',
  67547 => 'Morobe',
  6755 => 'Highlands',
  6756 => 'MP/Gulf/Tabubil/Kiunga',
  6759 => 'Islands',
);
