<?php
namespace Aws\CodePipeline\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the Amazon CodePipeline service.
 */
class CodePipelineException extends AwsException {}