<?php
namespace Aws\FreeTier;

use Aws\AwsClient;

/**
 * This client is used to interact with the **AWS Free Tier** service.
 * @method \Aws\Result getFreeTierUsage(array $args = [])
 * @method \GuzzleHttp\Promise\Promise getFreeTierUsageAsync(array $args = [])
 */
class FreeTierClient extends AwsClient {}
