<?php
namespace Aws\Outposts\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Outposts** service.
 */
class OutpostsException extends AwsException {}
