<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  38328 => 'Mitrovicë',
  383280 => 'Gjilan',
  38329 => 'Prizren',
  383290 => 'Ferizaj',
  38338 => 'Prishtinë',
  38339 => 'Pejë',
  383390 => 'Gjakovë',
);
