<?php
namespace Aws\SageMakerFeatureStoreRuntime\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon SageMaker Feature Store Runtime** service.
 */
class SageMakerFeatureStoreRuntimeException extends AwsException {}
